window.Gleam.initSearch([{"doc":"gleamgen","title":"gleamgen","content":"# Gleamgen\n\n[![Package Version](https://img.shields.io/hexpm/v/gleamgen?color=a6f0fc)](https://hex.pm/packages/gleamgen)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gleamgen/)\n\nA package for generating clean, type-checked, and formatted Gleam code ✏️\n\n## Installation 🚀\n\n```sh\ngleam add gleamgen\n```\n\n## Example\n\n```gleam\nimport gleam/io\nimport gleam/list\nimport gleam/string\nimport gleamgen/expression\nimport gleamgen/expression/block\nimport gleamgen/function\nimport gleamgen/import_\nimport gleamgen/module\nimport gleamgen/render\nimport gleamgen/types\n\npub fn main() {\n  let mod = {\n    use imported_io &lt;- module.with_import(import_.new([&quot;gleam&quot;, &quot;io&quot;]))\n    use imported_string &lt;- module.with_import(import_.new([&quot;gleam&quot;, &quot;string&quot;]))\n\n    // module_used is of type Expression(String)\n    use module_used &lt;- module.with_constant(\n      module.DefinitionDetails(\n        name: &quot;module_used&quot;,\n        is_public: False,\n        attributes: [],\n      ),\n      expression.string(&quot;Gleamgen&quot;),\n    )\n\n    use greeter &lt;- module.with_function(\n      module.DefinitionDetails(\n        name: &quot;greeter&quot;,\n        is_public: False,\n        attributes: [],\n      ),\n      function.new1(\n        arg1: #(&quot;greeting&quot;, types.string),\n        // we have said that greeter returns a string, so handler returning anything\n        // else would be a type error\n        returns: types.string,\n        handler: fn(greeting) {\n          greeting\n          |&gt; expression.concat_string(expression.string(&quot; from &quot;))\n          // trying to concatenate any other type would be a compilation error\n          |&gt; expression.concat_string(module_used)\n        },\n      ),\n    )\n\n    // Let&#39;s pick a greeting that we will use inside the generated code\n    let assert [outer_greeting, ..] =\n      list.shuffle([\n        expression.string(&quot;Howdy&quot;),\n        expression.string(&quot;Hello&quot;),\n        expression.call2(\n          // If this is not the selected greeting, gleam/string will not be\n          // imported in the final code\n          import_.function2(imported_string, string.repeat),\n          expression.string(&quot;Hi&quot;),\n          expression.int(5),\n        ),\n      ])\n\n    use _main &lt;- module.with_function(\n      module.DefinitionDetails(name: &quot;main&quot;, is_public: True, attributes: []),\n      function.new0(types.nil, fn() {\n        {\n          use greeting &lt;- block.with_let_declaration(\n            &quot;greeting&quot;,\n            expression.call1(greeter, outer_greeting),\n          )\n          block.ending_block(expression.call1(\n            // reference the actual io.println function to get the name and\n            // the type signature\n            import_.function1(imported_io, io.println),\n            greeting,\n          ))\n        }\n        |&gt; block.build()\n      }),\n    )\n\n    module.eof()\n  }\n\n  mod\n  |&gt; module.render(render.default_context())\n  |&gt; render.to_string()\n  |&gt; io.println()\n}\n```\n\nThis will generate something like:\n\n```gleam\nimport gleam/io\n\nconst module_used = &quot;Gleamgen&quot;\n\nfn greeter(greeting: String) -&gt; String {\n  greeting &lt;&gt; &quot; from &quot; &lt;&gt; module_used\n}\n\npub fn main() -&gt; Nil {\n  let greeting = greeter(&quot;Hello&quot;)\n  io.println(greeting)\n}\n```\n\nIn general, there are two versions of every gleamgen function:\n\n- The version with phantom types to ensure type safety of the generated code\n- The untyped version (generally with the suffix `_unchecked`)\n\nWhen possible, use the typed version to ensure the correctness of the generated code.\n\nHowever, in cases where you are dynamically generating the arguments or the\ntypes of functions, you will have to use the unchecked versions.\n\nYou can easily integrate between the two with functions such as\n`expression.to_unchecked` or `expression.unsafe_from_unchecked`\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gleamgen&gt;.\nAlso check out the examples folder (or the tests).\n\nNote: There are still a lot of basic functions that have yet to be implemented, and\nthe way things like generics are handled are subject to change\n","url":"index.html"},{"doc":"gleamgen/render","title":"Context","content":"pub type Context {\n  Context(\n    render_types: Bool,\n    include_brackets_current_level: Bool,\n  )\n}\n\nContext(render_types: Bool, include_brackets_current_level: Bool)\n\n\nSynonyms:\ngleamgen/render.Context\ngleamgen/render Context","url":"gleamgen/render.html#Context"},{"doc":"gleamgen/render","title":"Rendered","content":"pub type Rendered {\n  Render(doc: doc.Document, details: RenderedDetails)\n}\n\nRender(doc: doc.Document, details: RenderedDetails)\n\n\nSynonyms:\ngleamgen/render.Rendered\ngleamgen/render Rendered","url":"gleamgen/render.html#Rendered"},{"doc":"gleamgen/render","title":"RenderedDetails","content":"pub type RenderedDetails {\n  RenderedDetails(used_imports: List(String))\n}\n\nRenderedDetails(used_imports: List(String))\n\n\nSynonyms:\ngleamgen/render.RenderedDetails\ngleamgen/render RenderedDetails","url":"gleamgen/render.html#RenderedDetails"},{"doc":"gleamgen/render","title":"empty_details","content":"pub const empty_details: RenderedDetails\n\nSynonyms:\ngleamgen/render.empty_details\ngleamgen/render empty_details","url":"gleamgen/render.html#empty_details"},{"doc":"gleamgen/render","title":"default_context","content":"pub fn default_context() -&gt; Context\n\nSynonyms:\ngleamgen/render.default_context\ngleamgen/render default_context","url":"gleamgen/render.html#default_context"},{"doc":"gleamgen/render","title":"merge_details","content":"pub fn merge_details(\n  first: RenderedDetails,\n  second: RenderedDetails,\n) -&gt; RenderedDetails\n\nSynonyms:\ngleamgen/render.merge_details\ngleamgen/render merge_details","url":"gleamgen/render.html#merge_details"},{"doc":"gleamgen/render","title":"to_string","content":"pub fn to_string(to_render: Rendered) -&gt; String\n\nSynonyms:\ngleamgen/render.to_string\ngleamgen/render to_string","url":"gleamgen/render.html#to_string"},{"doc":"gleamgen/render","title":"gleamgen/render","content":"","url":"gleamgen/render.html"},{"doc":"gleamgen/types","title":"GeneratedType","content":"pub opaque type GeneratedType(type_)\n\n\nSynonyms:\ngleamgen/types.GeneratedType\ngleamgen/types GeneratedType","url":"gleamgen/types.html#GeneratedType"},{"doc":"gleamgen/types","title":"Unchecked","content":"pub type Unchecked\n\n\nSynonyms:\ngleamgen/types.Unchecked\ngleamgen/types Unchecked","url":"gleamgen/types.html#Unchecked"},{"doc":"gleamgen/types","title":"bool","content":"pub const bool: GeneratedType(Bool)\n\nSynonyms:\ngleamgen/types.bool\ngleamgen/types bool","url":"gleamgen/types.html#bool"},{"doc":"gleamgen/types","title":"float","content":"pub const float: GeneratedType(Float)\n\nSynonyms:\ngleamgen/types.float\ngleamgen/types float","url":"gleamgen/types.html#float"},{"doc":"gleamgen/types","title":"int","content":"pub const int: GeneratedType(Int)\n\nSynonyms:\ngleamgen/types.int\ngleamgen/types int","url":"gleamgen/types.html#int"},{"doc":"gleamgen/types","title":"nil","content":"pub const nil: GeneratedType(Nil)\n\nSynonyms:\ngleamgen/types.nil\ngleamgen/types nil","url":"gleamgen/types.html#nil"},{"doc":"gleamgen/types","title":"string","content":"pub const string: GeneratedType(String)\n\nSynonyms:\ngleamgen/types.string\ngleamgen/types string","url":"gleamgen/types.html#string"},{"doc":"gleamgen/types","title":"function0","content":"pub fn function0(\n  returns: GeneratedType(a),\n) -&gt; GeneratedType(fn() -&gt; a)\n\nSynonyms:\ngleamgen/types.function0\ngleamgen/types function0","url":"gleamgen/types.html#function0"},{"doc":"gleamgen/types","title":"function1","content":"pub fn function1(\n  arg1: GeneratedType(a),\n  returns: GeneratedType(b),\n) -&gt; GeneratedType(fn(a) -&gt; b)\n\nSynonyms:\ngleamgen/types.function1\ngleamgen/types function1","url":"gleamgen/types.html#function1"},{"doc":"gleamgen/types","title":"function2","content":"pub fn function2(\n  arg1: GeneratedType(a),\n  arg2: GeneratedType(b),\n  returns: GeneratedType(c),\n) -&gt; GeneratedType(fn(a, b) -&gt; c)\n\nSynonyms:\ngleamgen/types.function2\ngleamgen/types function2","url":"gleamgen/types.html#function2"},{"doc":"gleamgen/types","title":"function3","content":"pub fn function3(\n  arg1: GeneratedType(a),\n  arg2: GeneratedType(b),\n  arg3: GeneratedType(c),\n  returns: GeneratedType(d),\n) -&gt; GeneratedType(fn(a, b, c) -&gt; d)\n\nSynonyms:\ngleamgen/types.function3\ngleamgen/types function3","url":"gleamgen/types.html#function3"},{"doc":"gleamgen/types","title":"function4","content":"pub fn function4(\n  arg1: GeneratedType(a),\n  arg2: GeneratedType(b),\n  arg3: GeneratedType(c),\n  arg4: GeneratedType(d),\n  returns: GeneratedType(e),\n) -&gt; GeneratedType(fn(a, b, c, d) -&gt; e)\n\nSynonyms:\ngleamgen/types.function4\ngleamgen/types function4","url":"gleamgen/types.html#function4"},{"doc":"gleamgen/types","title":"function5","content":"pub fn function5(\n  arg1: GeneratedType(a),\n  arg2: GeneratedType(b),\n  arg3: GeneratedType(c),\n  arg4: GeneratedType(d),\n  arg5: GeneratedType(e),\n  returns: GeneratedType(f),\n) -&gt; GeneratedType(fn(a, b, c, d, e) -&gt; f)\n\nSynonyms:\ngleamgen/types.function5\ngleamgen/types function5","url":"gleamgen/types.html#function5"},{"doc":"gleamgen/types","title":"function6","content":"pub fn function6(\n  arg1: GeneratedType(a),\n  arg2: GeneratedType(b),\n  arg3: GeneratedType(c),\n  arg4: GeneratedType(d),\n  arg5: GeneratedType(e),\n  arg6: GeneratedType(f),\n  returns: GeneratedType(g),\n) -&gt; GeneratedType(fn(a, b, c, d, e, f) -&gt; g)\n\nSynonyms:\ngleamgen/types.function6\ngleamgen/types function6","url":"gleamgen/types.html#function6"},{"doc":"gleamgen/types","title":"function7","content":"pub fn function7(\n  arg1: GeneratedType(a),\n  arg2: GeneratedType(b),\n  arg3: GeneratedType(c),\n  arg4: GeneratedType(d),\n  arg5: GeneratedType(e),\n  arg6: GeneratedType(f),\n  arg7: GeneratedType(g),\n  returns: GeneratedType(h),\n) -&gt; GeneratedType(fn(a, b, c, d, e, f, g) -&gt; h)\n\nSynonyms:\ngleamgen/types.function7\ngleamgen/types function7","url":"gleamgen/types.html#function7"},{"doc":"gleamgen/types","title":"function8","content":"pub fn function8(\n  arg1: GeneratedType(a),\n  arg2: GeneratedType(b),\n  arg3: GeneratedType(c),\n  arg4: GeneratedType(d),\n  arg5: GeneratedType(e),\n  arg6: GeneratedType(f),\n  arg7: GeneratedType(g),\n  arg8: GeneratedType(h),\n  returns: GeneratedType(i),\n) -&gt; GeneratedType(fn(a, b, c, d, e, f, g, h) -&gt; i)\n\nSynonyms:\ngleamgen/types.function8\ngleamgen/types function8","url":"gleamgen/types.html#function8"},{"doc":"gleamgen/types","title":"function9","content":"pub fn function9(\n  arg1: GeneratedType(a),\n  arg2: GeneratedType(b),\n  arg3: GeneratedType(c),\n  arg4: GeneratedType(d),\n  arg5: GeneratedType(e),\n  arg6: GeneratedType(f),\n  arg7: GeneratedType(g),\n  arg8: GeneratedType(h),\n  arg9: GeneratedType(i),\n  returns: GeneratedType(j),\n) -&gt; GeneratedType(fn(a, b, c, d, e, f, g, h, i) -&gt; j)\n\nSynonyms:\ngleamgen/types.function9\ngleamgen/types function9","url":"gleamgen/types.html#function9"},{"doc":"gleamgen/types","title":"generic","content":"pub fn generic(name: String) -&gt; GeneratedType(a)\n\nSynonyms:\ngleamgen/types.generic\ngleamgen/types generic","url":"gleamgen/types.html#generic"},{"doc":"gleamgen/types","title":"get_return_type","content":"pub fn get_return_type(\n  function: GeneratedType(a),\n) -&gt; GeneratedType(Unchecked)\n\nSynonyms:\ngleamgen/types.get_return_type\ngleamgen/types get_return_type","url":"gleamgen/types.html#get_return_type"},{"doc":"gleamgen/types","title":"list","content":"pub fn list(type_: GeneratedType(a)) -&gt; GeneratedType(List(a))\n\nSynonyms:\ngleamgen/types.list\ngleamgen/types list","url":"gleamgen/types.html#list"},{"doc":"gleamgen/types","title":"reference","content":"pub fn reference(: a) -&gt; GeneratedType(a)\n\nSynonyms:\ngleamgen/types.reference\ngleamgen/types reference","url":"gleamgen/types.html#reference"},{"doc":"gleamgen/types","title":"render_type","content":"pub fn render_type(\n  type_: GeneratedType(a),\n) -&gt; Result(Rendered, Nil)\n\nSynonyms:\ngleamgen/types.render_type\ngleamgen/types render_type","url":"gleamgen/types.html#render_type"},{"doc":"gleamgen/types","title":"result","content":"pub fn result(\n  ok_type: GeneratedType(a),\n  err_type: GeneratedType(b),\n) -&gt; GeneratedType(Result(a, b))\n\nSynonyms:\ngleamgen/types.result\ngleamgen/types result","url":"gleamgen/types.html#result"},{"doc":"gleamgen/types","title":"to_unchecked","content":"pub fn to_unchecked(\n  type_: GeneratedType(a),\n) -&gt; GeneratedType(Unchecked)\n\nSynonyms:\ngleamgen/types.to_unchecked\ngleamgen/types to_unchecked","url":"gleamgen/types.html#to_unchecked"},{"doc":"gleamgen/types","title":"tuple1","content":"pub fn tuple1(type1: GeneratedType(a)) -&gt; GeneratedType(#(a))\n\nSynonyms:\ngleamgen/types.tuple1\ngleamgen/types tuple1","url":"gleamgen/types.html#tuple1"},{"doc":"gleamgen/types","title":"tuple2","content":"pub fn tuple2(\n  type1: GeneratedType(a),\n  type2: GeneratedType(b),\n) -&gt; GeneratedType(#(a, b))\n\nSynonyms:\ngleamgen/types.tuple2\ngleamgen/types tuple2","url":"gleamgen/types.html#tuple2"},{"doc":"gleamgen/types","title":"tuple3","content":"pub fn tuple3(\n  type1: GeneratedType(a),\n  type2: GeneratedType(b),\n  type3: GeneratedType(c),\n) -&gt; GeneratedType(#(a, b, c))\n\nSynonyms:\ngleamgen/types.tuple3\ngleamgen/types tuple3","url":"gleamgen/types.html#tuple3"},{"doc":"gleamgen/types","title":"tuple4","content":"pub fn tuple4(\n  type1: GeneratedType(a),\n  type2: GeneratedType(b),\n  type3: GeneratedType(c),\n  type4: GeneratedType(d),\n) -&gt; GeneratedType(#(a, b, c, d))\n\nSynonyms:\ngleamgen/types.tuple4\ngleamgen/types tuple4","url":"gleamgen/types.html#tuple4"},{"doc":"gleamgen/types","title":"tuple5","content":"pub fn tuple5(\n  type1: GeneratedType(a),\n  type2: GeneratedType(b),\n  type3: GeneratedType(c),\n  type4: GeneratedType(d),\n  type5: GeneratedType(e),\n) -&gt; GeneratedType(#(a, b, c, d, e))\n\nSynonyms:\ngleamgen/types.tuple5\ngleamgen/types tuple5","url":"gleamgen/types.html#tuple5"},{"doc":"gleamgen/types","title":"tuple6","content":"pub fn tuple6(\n  type1: GeneratedType(a),\n  type2: GeneratedType(b),\n  type3: GeneratedType(c),\n  type4: GeneratedType(d),\n  type5: GeneratedType(e),\n  type6: GeneratedType(f),\n) -&gt; GeneratedType(#(a, b, c, d, e, f))\n\nSynonyms:\ngleamgen/types.tuple6\ngleamgen/types tuple6","url":"gleamgen/types.html#tuple6"},{"doc":"gleamgen/types","title":"tuple7","content":"pub fn tuple7(\n  type1: GeneratedType(a),\n  type2: GeneratedType(b),\n  type3: GeneratedType(c),\n  type4: GeneratedType(d),\n  type5: GeneratedType(e),\n  type6: GeneratedType(f),\n  type7: GeneratedType(g),\n) -&gt; GeneratedType(#(a, b, c, d, e, f, g))\n\nSynonyms:\ngleamgen/types.tuple7\ngleamgen/types tuple7","url":"gleamgen/types.html#tuple7"},{"doc":"gleamgen/types","title":"tuple8","content":"pub fn tuple8(\n  type1: GeneratedType(a),\n  type2: GeneratedType(b),\n  type3: GeneratedType(c),\n  type4: GeneratedType(d),\n  type5: GeneratedType(e),\n  type6: GeneratedType(f),\n  type7: GeneratedType(g),\n  type8: GeneratedType(h),\n) -&gt; GeneratedType(#(a, b, c, d, e, f, g, h))\n\nSynonyms:\ngleamgen/types.tuple8\ngleamgen/types tuple8","url":"gleamgen/types.html#tuple8"},{"doc":"gleamgen/types","title":"tuple9","content":"pub fn tuple9(\n  type1: GeneratedType(a),\n  type2: GeneratedType(b),\n  type3: GeneratedType(c),\n  type4: GeneratedType(d),\n  type5: GeneratedType(e),\n  type6: GeneratedType(f),\n  type7: GeneratedType(g),\n  type8: GeneratedType(h),\n  type9: GeneratedType(i),\n) -&gt; GeneratedType(#(a, b, c, d, e, f, g, h, i))\n\nSynonyms:\ngleamgen/types.tuple9\ngleamgen/types tuple9","url":"gleamgen/types.html#tuple9"},{"doc":"gleamgen/types","title":"unchecked","content":"pub fn unchecked() -&gt; GeneratedType(a)\n\nSynonyms:\ngleamgen/types.unchecked\ngleamgen/types unchecked","url":"gleamgen/types.html#unchecked"},{"doc":"gleamgen/types","title":"unchecked_function","content":"pub fn unchecked_function(\n  args: List(GeneratedType(Unchecked)),\n  returns: GeneratedType(Unchecked),\n) -&gt; GeneratedType(a)\n\nSynonyms:\ngleamgen/types.unchecked_function\ngleamgen/types unchecked_function","url":"gleamgen/types.html#unchecked_function"},{"doc":"gleamgen/types","title":"unchecked_ident","content":"pub fn unchecked_ident(name: String) -&gt; GeneratedType(a)\n\nSynonyms:\ngleamgen/types.unchecked_ident\ngleamgen/types unchecked_ident","url":"gleamgen/types.html#unchecked_ident"},{"doc":"gleamgen/types","title":"unsafe_from_unchecked","content":"pub fn unsafe_from_unchecked(\n  type_: GeneratedType(Unchecked),\n) -&gt; GeneratedType(a)\n\nSynonyms:\ngleamgen/types.unsafe_from_unchecked\ngleamgen/types unsafe_from_unchecked","url":"gleamgen/types.html#unsafe_from_unchecked"},{"doc":"gleamgen/types","title":"gleamgen/types","content":"","url":"gleamgen/types.html"},{"doc":"gleamgen/expression","title":"Expression","content":"pub opaque type Expression(type_)\n\n\nSynonyms:\ngleamgen/expression.Expression\ngleamgen/expression Expression","url":"gleamgen/expression.html#Expression"},{"doc":"gleamgen/expression","title":"MathOperator","content":"pub type MathOperator {\n  Add\n  Sub\n  Mul\n  Div\n  GreaterThan\n  GreaterThanOrEqual\n  LessThan\n  LessThanOrEqual\n}\n See `math_operator` and `math_operator_float`\nAdd\n\n\nSub\n\n\nMul\n\n\nDiv\n\n\nGreaterThan\n\n\nGreaterThanOrEqual\n\n\nLessThan\n\n\nLessThanOrEqual\n\n\nSynonyms:\ngleamgen/expression.MathOperator\ngleamgen/expression MathOperator","url":"gleamgen/expression.html#MathOperator"},{"doc":"gleamgen/expression","title":"Statement","content":"pub type Statement {\n  LetDeclaration(\n    String,\n    Expression(types.Unchecked),\n    assert_: Bool,\n  )\n  ExpressionStatement(Expression(types.Unchecked))\n}\n\nLetDeclaration(\n  String,\n  Expression(types.Unchecked),\n  assert_: Bool,\n)\n\n\nExpressionStatement(Expression(types.Unchecked))\n\n\nSynonyms:\ngleamgen/expression.Statement\ngleamgen/expression Statement","url":"gleamgen/expression.html#Statement"},{"doc":"gleamgen/expression","title":"construct1","content":"pub const construct1: fn(Expression(fn(a) -&gt; b), Expression(a)) -&gt;\n  Expression(b)\n\nSynonyms:\ngleamgen/expression.construct1\ngleamgen/expression construct1","url":"gleamgen/expression.html#construct1"},{"doc":"gleamgen/expression","title":"construct2","content":"pub const construct2: fn(\n  Expression(fn(a, b) -&gt; c),\n  Expression(a),\n  Expression(b),\n) -&gt; Expression(c)\n\nSynonyms:\ngleamgen/expression.construct2\ngleamgen/expression construct2","url":"gleamgen/expression.html#construct2"},{"doc":"gleamgen/expression","title":"construct3","content":"pub const construct3: fn(\n  Expression(fn(a, b, c) -&gt; d),\n  Expression(a),\n  Expression(b),\n  Expression(c),\n) -&gt; Expression(d)\n\nSynonyms:\ngleamgen/expression.construct3\ngleamgen/expression construct3","url":"gleamgen/expression.html#construct3"},{"doc":"gleamgen/expression","title":"construct4","content":"pub const construct4: fn(\n  Expression(fn(a, b, c, d) -&gt; e),\n  Expression(a),\n  Expression(b),\n  Expression(c),\n  Expression(d),\n) -&gt; Expression(e)\n\nSynonyms:\ngleamgen/expression.construct4\ngleamgen/expression construct4","url":"gleamgen/expression.html#construct4"},{"doc":"gleamgen/expression","title":"construct5","content":"pub const construct5: fn(\n  Expression(fn(a, b, c, d, e) -&gt; f),\n  Expression(a),\n  Expression(b),\n  Expression(c),\n  Expression(d),\n  Expression(e),\n) -&gt; Expression(f)\n\nSynonyms:\ngleamgen/expression.construct5\ngleamgen/expression construct5","url":"gleamgen/expression.html#construct5"},{"doc":"gleamgen/expression","title":"construct6","content":"pub const construct6: fn(\n  Expression(fn(a, b, c, d, e, f) -&gt; g),\n  Expression(a),\n  Expression(b),\n  Expression(c),\n  Expression(d),\n  Expression(e),\n  Expression(f),\n) -&gt; Expression(g)\n\nSynonyms:\ngleamgen/expression.construct6\ngleamgen/expression construct6","url":"gleamgen/expression.html#construct6"},{"doc":"gleamgen/expression","title":"construct7","content":"pub const construct7: fn(\n  Expression(fn(a, b, c, d, e, f, g) -&gt; h),\n  Expression(a),\n  Expression(b),\n  Expression(c),\n  Expression(d),\n  Expression(e),\n  Expression(f),\n  Expression(g),\n) -&gt; Expression(h)\n\nSynonyms:\ngleamgen/expression.construct7\ngleamgen/expression construct7","url":"gleamgen/expression.html#construct7"},{"doc":"gleamgen/expression","title":"construct8","content":"pub const construct8: fn(\n  Expression(fn(a, b, c, d, e, f, g, h) -&gt; i),\n  Expression(a),\n  Expression(b),\n  Expression(c),\n  Expression(d),\n  Expression(e),\n  Expression(f),\n  Expression(g),\n  Expression(h),\n) -&gt; Expression(i)\n\nSynonyms:\ngleamgen/expression.construct8\ngleamgen/expression construct8","url":"gleamgen/expression.html#construct8"},{"doc":"gleamgen/expression","title":"construct9","content":"pub const construct9: fn(\n  Expression(fn(a, b, c, d, e, f, g, h, i) -&gt; j),\n  Expression(a),\n  Expression(b),\n  Expression(c),\n  Expression(d),\n  Expression(e),\n  Expression(f),\n  Expression(g),\n  Expression(h),\n  Expression(i),\n) -&gt; Expression(j)\n\nSynonyms:\ngleamgen/expression.construct9\ngleamgen/expression construct9","url":"gleamgen/expression.html#construct9"},{"doc":"gleamgen/expression","title":"bool","content":"pub fn bool(value: Bool) -&gt; Expression(Bool)\n\nSynonyms:\ngleamgen/expression.bool\ngleamgen/expression bool","url":"gleamgen/expression.html#bool"},{"doc":"gleamgen/expression","title":"call0","content":"pub fn call0(func: Expression(fn() -&gt; a)) -&gt; Expression(a)\n Call a function or constructor with no arguments\n \n expression.call0(\n   import_.function0(dict_module, dict.new)\n )\n |&gt; expression.render(render.default_context())\n |&gt; render.to_string()\n // -&gt; &quot;dict.new()&quot;\n \nSynonyms:\ngleamgen/expression.call0\ngleamgen/expression call0","url":"gleamgen/expression.html#call0"},{"doc":"gleamgen/expression","title":"call1","content":"pub fn call1(\n  func: Expression(fn(a) -&gt; b),\n  arg1: Expression(a),\n) -&gt; Expression(b)\n Call a function or constructor with one argument\n See `call0`\nSynonyms:\ngleamgen/expression.call1\ngleamgen/expression call1","url":"gleamgen/expression.html#call1"},{"doc":"gleamgen/expression","title":"call2","content":"pub fn call2(\n  func: Expression(fn(a, b) -&gt; c),\n  arg1: Expression(a),\n  arg2: Expression(b),\n) -&gt; Expression(c)\n Call a function or constructor with two arguments\n See `call0`\nSynonyms:\ngleamgen/expression.call2\ngleamgen/expression call2","url":"gleamgen/expression.html#call2"},{"doc":"gleamgen/expression","title":"call3","content":"pub fn call3(\n  func: Expression(fn(a, b, c) -&gt; d),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n) -&gt; Expression(d)\n Call a function or constructor with three arguments\n See `call0`\nSynonyms:\ngleamgen/expression.call3\ngleamgen/expression call3","url":"gleamgen/expression.html#call3"},{"doc":"gleamgen/expression","title":"call4","content":"pub fn call4(\n  func: Expression(fn(a, b, c, d) -&gt; e),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n) -&gt; Expression(e)\n Call a function or constructor with four arguments\n See `call0`\nSynonyms:\ngleamgen/expression.call4\ngleamgen/expression call4","url":"gleamgen/expression.html#call4"},{"doc":"gleamgen/expression","title":"call5","content":"pub fn call5(\n  func: Expression(fn(a, b, c, d, e) -&gt; f),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n) -&gt; Expression(f)\n Call a function or constructor with five arguments\n See `call0`\nSynonyms:\ngleamgen/expression.call5\ngleamgen/expression call5","url":"gleamgen/expression.html#call5"},{"doc":"gleamgen/expression","title":"call6","content":"pub fn call6(\n  func: Expression(fn(a, b, c, d, e, f) -&gt; g),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n  arg6: Expression(f),\n) -&gt; Expression(g)\n Call a function or constructor with six arguments\n See `call0`\nSynonyms:\ngleamgen/expression.call6\ngleamgen/expression call6","url":"gleamgen/expression.html#call6"},{"doc":"gleamgen/expression","title":"call7","content":"pub fn call7(\n  func: Expression(fn(a, b, c, d, e, f, g) -&gt; h),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n  arg6: Expression(f),\n  arg7: Expression(g),\n) -&gt; Expression(h)\n Call a function or constructor with seven arguments\n See `call0`\nSynonyms:\ngleamgen/expression.call7\ngleamgen/expression call7","url":"gleamgen/expression.html#call7"},{"doc":"gleamgen/expression","title":"call8","content":"pub fn call8(\n  func: Expression(fn(a, b, c, d, e, f, g, h) -&gt; i),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n  arg6: Expression(f),\n  arg7: Expression(g),\n  arg8: Expression(h),\n) -&gt; Expression(i)\n Call a function or constructor with eight arguments\n See `call0`\nSynonyms:\ngleamgen/expression.call8\ngleamgen/expression call8","url":"gleamgen/expression.html#call8"},{"doc":"gleamgen/expression","title":"call9","content":"pub fn call9(\n  func: Expression(fn(a, b, c, d, e, f, g, h, i) -&gt; j),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n  arg6: Expression(f),\n  arg7: Expression(g),\n  arg8: Expression(h),\n  arg9: Expression(i),\n) -&gt; Expression(j)\n Call a function or constructor with nine arguments\n See `call0`\nSynonyms:\ngleamgen/expression.call9\ngleamgen/expression call9","url":"gleamgen/expression.html#call9"},{"doc":"gleamgen/expression","title":"call_unchecked","content":"pub fn call_unchecked(\n  func: Expression(Unchecked),\n  args: List(Expression(Unchecked)),\n) -&gt; Expression(Unchecked)\n Call a function or constructor without type checking\nSynonyms:\ngleamgen/expression.call_unchecked\ngleamgen/expression call_unchecked","url":"gleamgen/expression.html#call_unchecked"},{"doc":"gleamgen/expression","title":"concat_string","content":"pub fn concat_string(\n  expr1: Expression(String),\n  expr2: Expression(String),\n) -&gt; Expression(String)\n Use the &lt;&gt; operator to concatenate two strings\n \n expression.concat_string(expression.string(&quot;hello &quot;), expression.string(&quot;world&quot;))\n |&gt; expression.render(render.default_context())\n |&gt; render.to_string()\n // -&gt; &quot;\\&quot;hello \\&quot; &lt;&gt; \\&quot;world\\&quot;&quot;\n \nSynonyms:\ngleamgen/expression.concat_string\ngleamgen/expression concat_string","url":"gleamgen/expression.html#concat_string"},{"doc":"gleamgen/expression","title":"construct0","content":"pub fn construct0(\n  constructor: Expression(fn() -&gt; a),\n) -&gt; Expression(a)\n\nSynonyms:\ngleamgen/expression.construct0\ngleamgen/expression construct0","url":"gleamgen/expression.html#construct0"},{"doc":"gleamgen/expression","title":"equals","content":"pub fn equals(\n  first: Expression(a),\n  second: Expression(a),\n) -&gt; Expression(Bool)\n\nSynonyms:\ngleamgen/expression.equals\ngleamgen/expression equals","url":"gleamgen/expression.html#equals"},{"doc":"gleamgen/expression","title":"error","content":"pub fn error(\n  err_value: Expression(a),\n) -&gt; Expression(Result(b, a))\n\nSynonyms:\ngleamgen/expression.error\ngleamgen/expression error","url":"gleamgen/expression.html#error"},{"doc":"gleamgen/expression","title":"float","content":"pub fn float(value: Float) -&gt; Expression(Float)\n\nSynonyms:\ngleamgen/expression.float\ngleamgen/expression float","url":"gleamgen/expression.html#float"},{"doc":"gleamgen/expression","title":"int","content":"pub fn int(value: Int) -&gt; Expression(Int)\n\nSynonyms:\ngleamgen/expression.int\ngleamgen/expression int","url":"gleamgen/expression.html#int"},{"doc":"gleamgen/expression","title":"list","content":"pub fn list(value: List(Expression(a))) -&gt; Expression(List(a))\n\nSynonyms:\ngleamgen/expression.list\ngleamgen/expression list","url":"gleamgen/expression.html#list"},{"doc":"gleamgen/expression","title":"list_prepend","content":"pub fn list_prepend(\n  prepending: List(Expression(a)),\n  original: Expression(List(a)),\n) -&gt; Expression(List(a))\n\nSynonyms:\ngleamgen/expression.list_prepend\ngleamgen/expression list_prepend","url":"gleamgen/expression.html#list_prepend"},{"doc":"gleamgen/expression","title":"math_operator","content":"pub fn math_operator(\n  expr1: Expression(Int),\n  op: MathOperator,\n  expr2: Expression(Int),\n) -&gt; Expression(Int)\n Apply a math operator to two expressions with the type of Int\n \n expression.math_operator(expression.int(3), expression.Add, expression.int(5))\n |&gt; expression.render(render.default_context())\n |&gt; render.to_string()\n // -&gt; &quot;3 + 5&quot;\n \nSynonyms:\ngleamgen/expression.math_operator\ngleamgen/expression math_operator","url":"gleamgen/expression.html#math_operator"},{"doc":"gleamgen/expression","title":"math_operator_float","content":"pub fn math_operator_float(\n  expr1: Expression(Float),\n  op: MathOperator,\n  expr2: Expression(Float),\n) -&gt; Expression(Int)\n Apply a math operator to two expressions with the type of Float\n \n expression.math_operator_float(\n   expression.float(3.3),\n   expression.GreaterThan,\n   expression.unchecked_ident(&quot;other_float&quot;)\n )\n |&gt; expression.render(render.default_context())\n |&gt; render.to_string()\n // -&gt; &quot;3 &gt;. other_float&quot;\n \nSynonyms:\ngleamgen/expression.math_operator_float\ngleamgen/expression math_operator_float","url":"gleamgen/expression.html#math_operator_float"},{"doc":"gleamgen/expression","title":"nil","content":"pub fn nil() -&gt; Expression(Nil)\n\nSynonyms:\ngleamgen/expression.nil\ngleamgen/expression nil","url":"gleamgen/expression.html#nil"},{"doc":"gleamgen/expression","title":"ok","content":"pub fn ok(ok_value: Expression(a)) -&gt; Expression(Result(a, b))\n\nSynonyms:\ngleamgen/expression.ok\ngleamgen/expression ok","url":"gleamgen/expression.html#ok"},{"doc":"gleamgen/expression","title":"panic_","content":"pub fn panic_(as_string: Option(String)) -&gt; Expression(a)\n Create a panic expression with an optional as clause\n \n expression.todo_(option.Some(&quot;ahhhhhh!!!&quot;))\n |&gt; expression.render(render.default_context())\n |&gt; render.to_string()\n // -&gt; &quot;panic as \\&quot;ahhhhhh!!!\\&quot;&quot;\n \nSynonyms:\ngleamgen/expression.panic_\ngleamgen/expression panic_","url":"gleamgen/expression.html#panic_"},{"doc":"gleamgen/expression","title":"render","content":"pub fn render(\n  expression: Expression(a),\n  context: Context,\n) -&gt; Rendered\n\nSynonyms:\ngleamgen/expression.render\ngleamgen/expression render","url":"gleamgen/expression.html#render"},{"doc":"gleamgen/expression","title":"render_statement","content":"pub fn render_statement(\n  statement: Statement,\n  context: Context,\n) -&gt; Rendered\n\nSynonyms:\ngleamgen/expression.render_statement\ngleamgen/expression render_statement","url":"gleamgen/expression.html#render_statement"},{"doc":"gleamgen/expression","title":"string","content":"pub fn string(value: String) -&gt; Expression(String)\n\nSynonyms:\ngleamgen/expression.string\ngleamgen/expression string","url":"gleamgen/expression.html#string"},{"doc":"gleamgen/expression","title":"to_unchecked","content":"pub fn to_unchecked(\n  type_: Expression(a),\n) -&gt; Expression(Unchecked)\n\nSynonyms:\ngleamgen/expression.to_unchecked\ngleamgen/expression to_unchecked","url":"gleamgen/expression.html#to_unchecked"},{"doc":"gleamgen/expression","title":"todo_","content":"pub fn todo_(as_string: Option(String)) -&gt; Expression(a)\n Create a todo expression with an optional as clause\n \n expression.todo_(option.Some(&quot;some unimplemented thing&quot;))\n |&gt; expression.render(render.default_context())\n |&gt; render.to_string()\n // -&gt; &quot;todo as \\&quot;some unimplemented thing\\&quot;&quot;\n \nSynonyms:\ngleamgen/expression.todo_\ngleamgen/expression todo_","url":"gleamgen/expression.html#todo_"},{"doc":"gleamgen/expression","title":"tuple1","content":"pub fn tuple1(arg1: Expression(a)) -&gt; Expression(#(a))\n\nSynonyms:\ngleamgen/expression.tuple1\ngleamgen/expression tuple1","url":"gleamgen/expression.html#tuple1"},{"doc":"gleamgen/expression","title":"tuple2","content":"pub fn tuple2(\n  arg1: Expression(a),\n  arg2: Expression(b),\n) -&gt; Expression(#(a, b))\n\nSynonyms:\ngleamgen/expression.tuple2\ngleamgen/expression tuple2","url":"gleamgen/expression.html#tuple2"},{"doc":"gleamgen/expression","title":"tuple3","content":"pub fn tuple3(\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n) -&gt; Expression(#(a, b, c))\n\nSynonyms:\ngleamgen/expression.tuple3\ngleamgen/expression tuple3","url":"gleamgen/expression.html#tuple3"},{"doc":"gleamgen/expression","title":"tuple4","content":"pub fn tuple4(\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n) -&gt; Expression(#(a, b, c, d))\n\nSynonyms:\ngleamgen/expression.tuple4\ngleamgen/expression tuple4","url":"gleamgen/expression.html#tuple4"},{"doc":"gleamgen/expression","title":"tuple5","content":"pub fn tuple5(\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n) -&gt; Expression(#(a, b, c, d, e))\n\nSynonyms:\ngleamgen/expression.tuple5\ngleamgen/expression tuple5","url":"gleamgen/expression.html#tuple5"},{"doc":"gleamgen/expression","title":"tuple6","content":"pub fn tuple6(\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n  arg6: Expression(f),\n) -&gt; Expression(#(a, b, c, d, e, f))\n\nSynonyms:\ngleamgen/expression.tuple6\ngleamgen/expression tuple6","url":"gleamgen/expression.html#tuple6"},{"doc":"gleamgen/expression","title":"tuple7","content":"pub fn tuple7(\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n  arg6: Expression(f),\n  arg7: Expression(g),\n) -&gt; Expression(#(a, b, c, d, e, f, g))\n\nSynonyms:\ngleamgen/expression.tuple7\ngleamgen/expression tuple7","url":"gleamgen/expression.html#tuple7"},{"doc":"gleamgen/expression","title":"tuple8","content":"pub fn tuple8(\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n  arg6: Expression(f),\n  arg7: Expression(g),\n  arg8: Expression(h),\n) -&gt; Expression(#(a, b, c, d, e, f, g, h))\n\nSynonyms:\ngleamgen/expression.tuple8\ngleamgen/expression tuple8","url":"gleamgen/expression.html#tuple8"},{"doc":"gleamgen/expression","title":"tuple9","content":"pub fn tuple9(\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n  arg6: Expression(f),\n  arg7: Expression(g),\n  arg8: Expression(h),\n  arg9: Expression(i),\n) -&gt; Expression(#(a, b, c, d, e, f, g, h, i))\n\nSynonyms:\ngleamgen/expression.tuple9\ngleamgen/expression tuple9","url":"gleamgen/expression.html#tuple9"},{"doc":"gleamgen/expression","title":"type_","content":"pub fn type_(expr: Expression(a)) -&gt; GeneratedType(a)\n Get the internal type of an expression\nSynonyms:\ngleamgen/expression.type_\ngleamgen/expression type_","url":"gleamgen/expression.html#type_"},{"doc":"gleamgen/expression","title":"unchecked_ident","content":"pub fn unchecked_ident(value: String) -&gt; Expression(a)\n Provide an ident that could be of any type\nSynonyms:\ngleamgen/expression.unchecked_ident\ngleamgen/expression unchecked_ident","url":"gleamgen/expression.html#unchecked_ident"},{"doc":"gleamgen/expression","title":"unchecked_of_type","content":"pub fn unchecked_of_type(\n  value: String,\n  type_: GeneratedType(a),\n) -&gt; Expression(a)\n Provide a string to inject without any checking of the specified type\nSynonyms:\ngleamgen/expression.unchecked_of_type\ngleamgen/expression unchecked_of_type","url":"gleamgen/expression.html#unchecked_of_type"},{"doc":"gleamgen/expression","title":"unsafe_from_unchecked","content":"pub fn unsafe_from_unchecked(\n  type_: Expression(a),\n) -&gt; Expression(b)\n Convert an expression to any type without checking\nSynonyms:\ngleamgen/expression.unsafe_from_unchecked\ngleamgen/expression unsafe_from_unchecked","url":"gleamgen/expression.html#unsafe_from_unchecked"},{"doc":"gleamgen/expression","title":"gleamgen/expression","content":"","url":"gleamgen/expression.html"},{"doc":"gleamgen/types/variant","title":"Variant","content":"pub type Variant(a) {\n  Variant(\n    name: String,\n    arguments: List(\n      #(Option(String), types.GeneratedType(Unchecked)),\n    ),\n  )\n}\n\nVariant(\n  name: String,\n  arguments: List(\n    #(Option(String), types.GeneratedType(Unchecked)),\n  ),\n)\n\n\nSynonyms:\ngleamgen/types/variant.Variant\ngleamgen/types/variant Variant","url":"gleamgen/types/variant.html#Variant"},{"doc":"gleamgen/types/variant","title":"new","content":"pub fn new(name: String) -&gt; Variant(#())\n\nSynonyms:\ngleamgen/types/variant.new\ngleamgen/types/variant new","url":"gleamgen/types/variant.html#new"},{"doc":"gleamgen/types/variant","title":"to_unchecked","content":"pub fn to_unchecked(variant: Variant(a)) -&gt; Variant(Unchecked)\n\nSynonyms:\ngleamgen/types/variant.to_unchecked\ngleamgen/types/variant to_unchecked","url":"gleamgen/types/variant.html#to_unchecked"},{"doc":"gleamgen/types/variant","title":"with_argument","content":"pub fn with_argument(\n  old: Variant(a),\n  name: Option(String),\n  type_: GeneratedType(b),\n) -&gt; Variant(#(a, b))\n\nSynonyms:\ngleamgen/types/variant.with_argument\ngleamgen/types/variant with_argument","url":"gleamgen/types/variant.html#with_argument"},{"doc":"gleamgen/types/variant","title":"with_arguments_unchecked","content":"pub fn with_arguments_unchecked(\n  old: Variant(a),\n  variants: List(#(Option(String), GeneratedType(Unchecked))),\n) -&gt; Variant(Unchecked)\n\nSynonyms:\ngleamgen/types/variant.with_arguments_unchecked\ngleamgen/types/variant with_arguments_unchecked","url":"gleamgen/types/variant.html#with_arguments_unchecked"},{"doc":"gleamgen/types/variant","title":"gleamgen/types/variant","content":"","url":"gleamgen/types/variant.html"},{"doc":"gleamgen/types/custom","title":"CustomType","content":"pub type CustomType(repr, generics) {\n  CustomType(module: option.Option(String), name: String)\n}\n\nCustomType(module: option.Option(String), name: String)\n\n\nSynonyms:\ngleamgen/types/custom.CustomType\ngleamgen/types/custom CustomType","url":"gleamgen/types/custom.html#CustomType"},{"doc":"gleamgen/types/custom","title":"CustomTypeBuilder","content":"pub type CustomTypeBuilder(repr, variants, generics) {\n  CustomTypeBuilder(\n    variants: List(Variant(Unchecked)),\n    generics_list: List(String),\n    generics: generics,\n  )\n}\n\nCustomTypeBuilder(\n  variants: List(Variant(Unchecked)),\n  generics_list: List(String),\n  generics: generics,\n)\n\n\nSynonyms:\ngleamgen/types/custom.CustomTypeBuilder\ngleamgen/types/custom CustomTypeBuilder","url":"gleamgen/types/custom.html#CustomTypeBuilder"},{"doc":"gleamgen/types/custom","title":"Generics1","content":"pub type Generics1(a) =\n  #(#(), a)\n\n\nSynonyms:\ngleamgen/types/custom.Generics1\ngleamgen/types/custom Generics1","url":"gleamgen/types/custom.html#Generics1"},{"doc":"gleamgen/types/custom","title":"Generics2","content":"pub type Generics2(a, b) =\n  #(#(#(), a), b)\n\n\nSynonyms:\ngleamgen/types/custom.Generics2\ngleamgen/types/custom Generics2","url":"gleamgen/types/custom.html#Generics2"},{"doc":"gleamgen/types/custom","title":"Generics3","content":"pub type Generics3(a, b, c) =\n  #(#(#(#(), a), b), c)\n\n\nSynonyms:\ngleamgen/types/custom.Generics3\ngleamgen/types/custom Generics3","url":"gleamgen/types/custom.html#Generics3"},{"doc":"gleamgen/types/custom","title":"Generics4","content":"pub type Generics4(a, b, c, d) =\n  #(#(#(#(#(), a), b), c), d)\n\n\nSynonyms:\ngleamgen/types/custom.Generics4\ngleamgen/types/custom Generics4","url":"gleamgen/types/custom.html#Generics4"},{"doc":"gleamgen/types/custom","title":"Generics5","content":"pub type Generics5(a, b, c, d, e) =\n  #(#(#(#(#(#(), a), b), c), d), e)\n\n\nSynonyms:\ngleamgen/types/custom.Generics5\ngleamgen/types/custom Generics5","url":"gleamgen/types/custom.html#Generics5"},{"doc":"gleamgen/types/custom","title":"Generics6","content":"pub type Generics6(a, b, c, d, e, f) =\n  #(#(#(#(#(#(#(), a), b), c), d), e), f)\n\n\nSynonyms:\ngleamgen/types/custom.Generics6\ngleamgen/types/custom Generics6","url":"gleamgen/types/custom.html#Generics6"},{"doc":"gleamgen/types/custom","title":"Generics7","content":"pub type Generics7(a, b, c, d, e, f, g) =\n  #(#(#(#(#(#(#(#(), a), b), c), d), e), f), g)\n\n\nSynonyms:\ngleamgen/types/custom.Generics7\ngleamgen/types/custom Generics7","url":"gleamgen/types/custom.html#Generics7"},{"doc":"gleamgen/types/custom","title":"Generics8","content":"pub type Generics8(a, b, c, d, e, f, g, h) =\n  #(#(#(#(#(#(#(#(#(), a), b), c), d), e), f), g), h)\n\n\nSynonyms:\ngleamgen/types/custom.Generics8\ngleamgen/types/custom Generics8","url":"gleamgen/types/custom.html#Generics8"},{"doc":"gleamgen/types/custom","title":"Generics9","content":"pub type Generics9(a, b, c, d, e, f, g, h, i) =\n  #(#(#(#(#(#(#(#(#(#(), a), b), c), d), e), f), g), h), i)\n\n\nSynonyms:\ngleamgen/types/custom.Generics9\ngleamgen/types/custom Generics9","url":"gleamgen/types/custom.html#Generics9"},{"doc":"gleamgen/types/custom","title":"new","content":"pub fn new(\n  typed_representation: a,\n) -&gt; CustomTypeBuilder(a, #(), #())\n\nSynonyms:\ngleamgen/types/custom.new\ngleamgen/types/custom new","url":"gleamgen/types/custom.html#new"},{"doc":"gleamgen/types/custom","title":"new_unchecked","content":"pub fn new_unchecked(\n  typed_representation: a,\n  variants: List(Variant(Unchecked)),\n  generics_list: List(String),\n) -&gt; CustomTypeBuilder(a, b, List(GeneratedType(Unchecked)))\n\nSynonyms:\ngleamgen/types/custom.new_unchecked\ngleamgen/types/custom new_unchecked","url":"gleamgen/types/custom.html#new_unchecked"},{"doc":"gleamgen/types/custom","title":"render","content":"pub fn render(type_: CustomTypeBuilder(a, b, c)) -&gt; Rendered\n\nSynonyms:\ngleamgen/types/custom.render\ngleamgen/types/custom render","url":"gleamgen/types/custom.html#render"},{"doc":"gleamgen/types/custom","title":"to_type","content":"pub fn to_type(\n  input: CustomType(a, #()),\n) -&gt; GeneratedType(CustomType(a, #()))\n\nSynonyms:\ngleamgen/types/custom.to_type\ngleamgen/types/custom to_type","url":"gleamgen/types/custom.html#to_type"},{"doc":"gleamgen/types/custom","title":"to_type1","content":"pub fn to_type1(\n  input: CustomType(a, #(#(), GeneratedType(b))),\n  type1: GeneratedType(c),\n) -&gt; GeneratedType(CustomType(a, #(#(), GeneratedType(c))))\n\nSynonyms:\ngleamgen/types/custom.to_type1\ngleamgen/types/custom to_type1","url":"gleamgen/types/custom.html#to_type1"},{"doc":"gleamgen/types/custom","title":"to_type2","content":"pub fn to_type2(\n  input: CustomType(\n    a,\n    #(#(#(), GeneratedType(b)), GeneratedType(c)),\n  ),\n  type1: GeneratedType(d),\n  type2: GeneratedType(e),\n) -&gt; GeneratedType(\n  CustomType(a, #(#(#(), GeneratedType(d)), GeneratedType(e))),\n)\n\nSynonyms:\ngleamgen/types/custom.to_type2\ngleamgen/types/custom to_type2","url":"gleamgen/types/custom.html#to_type2"},{"doc":"gleamgen/types/custom","title":"to_type3","content":"pub fn to_type3(\n  input: CustomType(\n    a,\n    #(\n      #(#(#(), GeneratedType(b)), GeneratedType(c)),\n      GeneratedType(d),\n    ),\n  ),\n  type1: GeneratedType(e),\n  type2: GeneratedType(f),\n  type3: GeneratedType(g),\n) -&gt; GeneratedType(\n  CustomType(\n    a,\n    #(\n      #(#(#(), GeneratedType(e)), GeneratedType(f)),\n      GeneratedType(g),\n    ),\n  ),\n)\n\nSynonyms:\ngleamgen/types/custom.to_type3\ngleamgen/types/custom to_type3","url":"gleamgen/types/custom.html#to_type3"},{"doc":"gleamgen/types/custom","title":"to_type4","content":"pub fn to_type4(\n  input: CustomType(\n    a,\n    #(\n      #(\n        #(#(#(), GeneratedType(b)), GeneratedType(c)),\n        GeneratedType(d),\n      ),\n      GeneratedType(e),\n    ),\n  ),\n  type1: GeneratedType(f),\n  type2: GeneratedType(g),\n  type3: GeneratedType(h),\n  type4: GeneratedType(i),\n) -&gt; GeneratedType(\n  CustomType(\n    a,\n    #(\n      #(\n        #(#(#(), GeneratedType(f)), GeneratedType(g)),\n        GeneratedType(h),\n      ),\n      GeneratedType(i),\n    ),\n  ),\n)\n\nSynonyms:\ngleamgen/types/custom.to_type4\ngleamgen/types/custom to_type4","url":"gleamgen/types/custom.html#to_type4"},{"doc":"gleamgen/types/custom","title":"to_type5","content":"pub fn to_type5(\n  input: CustomType(\n    a,\n    #(\n      #(\n        #(\n          #(#(#(), GeneratedType(b)), GeneratedType(c)),\n          GeneratedType(d),\n        ),\n        GeneratedType(e),\n      ),\n      GeneratedType(f),\n    ),\n  ),\n  type1: GeneratedType(g),\n  type2: GeneratedType(h),\n  type3: GeneratedType(i),\n  type4: GeneratedType(j),\n  type5: GeneratedType(k),\n) -&gt; GeneratedType(\n  CustomType(\n    a,\n    #(\n      #(\n        #(\n          #(#(#(), GeneratedType(g)), GeneratedType(h)),\n          GeneratedType(i),\n        ),\n        GeneratedType(j),\n      ),\n      GeneratedType(k),\n    ),\n  ),\n)\n\nSynonyms:\ngleamgen/types/custom.to_type5\ngleamgen/types/custom to_type5","url":"gleamgen/types/custom.html#to_type5"},{"doc":"gleamgen/types/custom","title":"to_unchecked","content":"pub fn to_unchecked(\n  old: CustomTypeBuilder(a, b, c),\n) -&gt; CustomTypeBuilder(Unchecked, Nil, Nil)\n\nSynonyms:\ngleamgen/types/custom.to_unchecked\ngleamgen/types/custom to_unchecked","url":"gleamgen/types/custom.html#to_unchecked"},{"doc":"gleamgen/types/custom","title":"with_generic","content":"pub fn with_generic(\n  old: CustomTypeBuilder(a, b, c),\n  generic: String,\n) -&gt; CustomTypeBuilder(a, b, #(c, GeneratedType(d)))\n\nSynonyms:\ngleamgen/types/custom.with_generic\ngleamgen/types/custom with_generic","url":"gleamgen/types/custom.html#with_generic"},{"doc":"gleamgen/types/custom","title":"with_unchecked_variants","content":"pub fn with_unchecked_variants(\n  old: CustomTypeBuilder(a, b, c),\n  variants: fn(c) -&gt; List(Variant(Unchecked)),\n) -&gt; CustomTypeBuilder(a, Unchecked, c)\n\nSynonyms:\ngleamgen/types/custom.with_unchecked_variants\ngleamgen/types/custom with_unchecked_variants","url":"gleamgen/types/custom.html#with_unchecked_variants"},{"doc":"gleamgen/types/custom","title":"with_variant","content":"pub fn with_variant(\n  old: CustomTypeBuilder(a, b, c),\n  variant: fn(c) -&gt; Variant(d),\n) -&gt; CustomTypeBuilder(a, #(b, d), c)\n\nSynonyms:\ngleamgen/types/custom.with_variant\ngleamgen/types/custom with_variant","url":"gleamgen/types/custom.html#with_variant"},{"doc":"gleamgen/types/custom","title":"gleamgen/types/custom","content":"","url":"gleamgen/types/custom.html"},{"doc":"gleamgen/expression/constructor","title":"Constructor","content":"pub opaque type Constructor(construct_to, args, generics)\n Use to_expression[n] or to_expression_unchecked to create an expression from the constructor.\n\nSynonyms:\ngleamgen/expression/constructor.Constructor\ngleamgen/expression/constructor Constructor","url":"gleamgen/expression/constructor.html#Constructor"},{"doc":"gleamgen/expression/constructor","title":"Variants1","content":"pub type Variants1(a) =\n  #(#(), a)\n\n\nSynonyms:\ngleamgen/expression/constructor.Variants1\ngleamgen/expression/constructor Variants1","url":"gleamgen/expression/constructor.html#Variants1"},{"doc":"gleamgen/expression/constructor","title":"Variants2","content":"pub type Variants2(a, b) =\n  #(#(#(), a), b)\n\n\nSynonyms:\ngleamgen/expression/constructor.Variants2\ngleamgen/expression/constructor Variants2","url":"gleamgen/expression/constructor.html#Variants2"},{"doc":"gleamgen/expression/constructor","title":"Variants3","content":"pub type Variants3(a, b, c) =\n  #(#(#(#(), a), b), c)\n\n\nSynonyms:\ngleamgen/expression/constructor.Variants3\ngleamgen/expression/constructor Variants3","url":"gleamgen/expression/constructor.html#Variants3"},{"doc":"gleamgen/expression/constructor","title":"Variants4","content":"pub type Variants4(a, b, c, d) =\n  #(#(#(#(#(), a), b), c), d)\n\n\nSynonyms:\ngleamgen/expression/constructor.Variants4\ngleamgen/expression/constructor Variants4","url":"gleamgen/expression/constructor.html#Variants4"},{"doc":"gleamgen/expression/constructor","title":"Variants5","content":"pub type Variants5(a, b, c, d, e) =\n  #(#(#(#(#(#(), a), b), c), d), e)\n\n\nSynonyms:\ngleamgen/expression/constructor.Variants5\ngleamgen/expression/constructor Variants5","url":"gleamgen/expression/constructor.html#Variants5"},{"doc":"gleamgen/expression/constructor","title":"Variants6","content":"pub type Variants6(a, b, c, d, e, f) =\n  #(#(#(#(#(#(#(), a), b), c), d), e), f)\n\n\nSynonyms:\ngleamgen/expression/constructor.Variants6\ngleamgen/expression/constructor Variants6","url":"gleamgen/expression/constructor.html#Variants6"},{"doc":"gleamgen/expression/constructor","title":"Variants7","content":"pub type Variants7(a, b, c, d, e, f, g) =\n  #(#(#(#(#(#(#(#(), a), b), c), d), e), f), g)\n\n\nSynonyms:\ngleamgen/expression/constructor.Variants7\ngleamgen/expression/constructor Variants7","url":"gleamgen/expression/constructor.html#Variants7"},{"doc":"gleamgen/expression/constructor","title":"Variants8","content":"pub type Variants8(a, b, c, d, e, f, g, h) =\n  #(#(#(#(#(#(#(#(#(), a), b), c), d), e), f), g), h)\n\n\nSynonyms:\ngleamgen/expression/constructor.Variants8\ngleamgen/expression/constructor Variants8","url":"gleamgen/expression/constructor.html#Variants8"},{"doc":"gleamgen/expression/constructor","title":"Variants9","content":"pub type Variants9(a, b, c, d, e, f, g, h, i) =\n  #(#(#(#(#(#(#(#(#(#(), a), b), c), d), e), f), g), h), i)\n\n\nSynonyms:\ngleamgen/expression/constructor.Variants9\ngleamgen/expression/constructor Variants9","url":"gleamgen/expression/constructor.html#Variants9"},{"doc":"gleamgen/expression/constructor","title":"name","content":"pub fn name(constructor: Constructor(a, b, c)) -&gt; String\n\nSynonyms:\ngleamgen/expression/constructor.name\ngleamgen/expression/constructor name","url":"gleamgen/expression/constructor.html#name"},{"doc":"gleamgen/expression/constructor","title":"to_expression0","content":"pub fn to_expression0(\n  constructor: Constructor(a, #(), b),\n) -&gt; Expression(a)\n\nSynonyms:\ngleamgen/expression/constructor.to_expression0\ngleamgen/expression/constructor to_expression0","url":"gleamgen/expression/constructor.html#to_expression0"},{"doc":"gleamgen/expression/constructor","title":"to_expression1","content":"pub fn to_expression1(\n  constructor: Constructor(a, #(#(), b), c),\n) -&gt; Expression(fn(b) -&gt; CustomType(a, c))\n\nSynonyms:\ngleamgen/expression/constructor.to_expression1\ngleamgen/expression/constructor to_expression1","url":"gleamgen/expression/constructor.html#to_expression1"},{"doc":"gleamgen/expression/constructor","title":"to_expression2","content":"pub fn to_expression2(\n  constructor: Constructor(a, #(#(#(), b), c), d),\n) -&gt; Expression(fn(b, c) -&gt; CustomType(a, d))\n\nSynonyms:\ngleamgen/expression/constructor.to_expression2\ngleamgen/expression/constructor to_expression2","url":"gleamgen/expression/constructor.html#to_expression2"},{"doc":"gleamgen/expression/constructor","title":"to_expression3","content":"pub fn to_expression3(\n  constructor: Constructor(a, #(#(#(#(), b), c), d), e),\n) -&gt; Expression(fn(b, c, d) -&gt; CustomType(a, e))\n\nSynonyms:\ngleamgen/expression/constructor.to_expression3\ngleamgen/expression/constructor to_expression3","url":"gleamgen/expression/constructor.html#to_expression3"},{"doc":"gleamgen/expression/constructor","title":"to_expression4","content":"pub fn to_expression4(\n  constructor: Constructor(a, #(#(#(#(#(), b), c), d), e), f),\n) -&gt; Expression(fn(b, c, d, e) -&gt; a)\n\nSynonyms:\ngleamgen/expression/constructor.to_expression4\ngleamgen/expression/constructor to_expression4","url":"gleamgen/expression/constructor.html#to_expression4"},{"doc":"gleamgen/expression/constructor","title":"to_expression5","content":"pub fn to_expression5(\n  constructor: Constructor(\n    a,\n    #(#(#(#(#(#(), b), c), d), e), f),\n    g,\n  ),\n) -&gt; Expression(fn(b, c, d, e, f) -&gt; a)\n\nSynonyms:\ngleamgen/expression/constructor.to_expression5\ngleamgen/expression/constructor to_expression5","url":"gleamgen/expression/constructor.html#to_expression5"},{"doc":"gleamgen/expression/constructor","title":"to_expression6","content":"pub fn to_expression6(\n  constructor: Constructor(\n    a,\n    #(#(#(#(#(#(#(), b), c), d), e), f), g),\n    h,\n  ),\n) -&gt; Expression(fn(b, c, d, e, f, g) -&gt; a)\n\nSynonyms:\ngleamgen/expression/constructor.to_expression6\ngleamgen/expression/constructor to_expression6","url":"gleamgen/expression/constructor.html#to_expression6"},{"doc":"gleamgen/expression/constructor","title":"to_expression7","content":"pub fn to_expression7(\n  constructor: Constructor(\n    a,\n    #(#(#(#(#(#(#(#(), b), c), d), e), f), g), h),\n    i,\n  ),\n) -&gt; Expression(fn(b, c, d, e, f, g, h) -&gt; a)\n\nSynonyms:\ngleamgen/expression/constructor.to_expression7\ngleamgen/expression/constructor to_expression7","url":"gleamgen/expression/constructor.html#to_expression7"},{"doc":"gleamgen/expression/constructor","title":"to_expression8","content":"pub fn to_expression8(\n  constructor: Constructor(\n    a,\n    #(#(#(#(#(#(#(#(#(), b), c), d), e), f), g), h), i),\n    j,\n  ),\n) -&gt; Expression(fn(b, c, d, e, f, g, h, i) -&gt; a)\n\nSynonyms:\ngleamgen/expression/constructor.to_expression8\ngleamgen/expression/constructor to_expression8","url":"gleamgen/expression/constructor.html#to_expression8"},{"doc":"gleamgen/expression/constructor","title":"to_expression9","content":"pub fn to_expression9(\n  constructor: Constructor(\n    a,\n    #(#(#(#(#(#(#(#(#(#(), b), c), d), e), f), g), h), i), j),\n    k,\n  ),\n) -&gt; Expression(fn(b, c, d, e, f, g, h, i, j) -&gt; a)\n\nSynonyms:\ngleamgen/expression/constructor.to_expression9\ngleamgen/expression/constructor to_expression9","url":"gleamgen/expression/constructor.html#to_expression9"},{"doc":"gleamgen/expression/constructor","title":"to_expression_unchecked","content":"pub fn to_expression_unchecked(\n  constructor: Constructor(a, b, c),\n) -&gt; Expression(d)\n\nSynonyms:\ngleamgen/expression/constructor.to_expression_unchecked\ngleamgen/expression/constructor to_expression_unchecked","url":"gleamgen/expression/constructor.html#to_expression_unchecked"},{"doc":"gleamgen/expression/constructor","title":"unsafe_convert","content":"pub fn unsafe_convert(\n  constructor: Constructor(a, b, c),\n) -&gt; Constructor(a, d, e)\n\nSynonyms:\ngleamgen/expression/constructor.unsafe_convert\ngleamgen/expression/constructor unsafe_convert","url":"gleamgen/expression/constructor.html#unsafe_convert"},{"doc":"gleamgen/expression/constructor","title":"gleamgen/expression/constructor","content":"","url":"gleamgen/expression/constructor.html"},{"doc":"gleamgen/matcher","title":"Matcher","content":"pub opaque type Matcher(input, match_output)\n\n\nSynonyms:\ngleamgen/matcher.Matcher\ngleamgen/matcher Matcher","url":"gleamgen/matcher.html#Matcher"},{"doc":"gleamgen/matcher","title":"as_","content":"pub fn as_(\n  original: Matcher(a, b),\n  name: String,\n) -&gt; Matcher(a, Expression(a))\n\nSynonyms:\ngleamgen/matcher.as_\ngleamgen/matcher as_","url":"gleamgen/matcher.html#as_"},{"doc":"gleamgen/matcher","title":"bool_literal","content":"pub fn bool_literal(literal: Bool) -&gt; Matcher(Bool, Nil)\n\nSynonyms:\ngleamgen/matcher.bool_literal\ngleamgen/matcher bool_literal","url":"gleamgen/matcher.html#bool_literal"},{"doc":"gleamgen/matcher","title":"concat_string","content":"pub fn concat_string(\n  starting initial: String,\n  variable variable: String,\n) -&gt; Matcher(String, Expression(a))\n Match a string that starts with `initial`\n \n case_.new(expression.string(&quot;I love gleam&quot;))\n |&gt; case_.with_matcher(\n   matcher.concat_string(starting: &quot;I love &quot;, variable: &quot;thing&quot;),\n   fn(thing) {\n     expression.string(&quot;I love &quot;)\n     |&gt; expression.concat_string(thing)\n     |&gt; expression.concat_string(expression.string(&quot; too&quot;))\n   },\n )\n |&gt; case_.with_matcher(matcher.variable(&quot;_&quot;), fn(_) {\n   expression.string(&quot;interesting&quot;)\n })\n |&gt; case_.build_expression()\n |&gt; expression.render(render.default_context())\n |&gt; render.to_string()\n // -&gt; &quot;case \\&quot;I love gleam\\&quot; {\n  \\&quot;I love \\&quot; &lt;&gt; thing -&gt; \\&quot;I love \\&quot; &lt;&gt; thing &lt;&gt; \\&quot; too\\&quot;\n  _ -&gt; \\&quot;Interesting\\&quot;\n }&quot;\n \nSynonyms:\ngleamgen/matcher.concat_string\ngleamgen/matcher concat_string","url":"gleamgen/matcher.html#concat_string"},{"doc":"gleamgen/matcher","title":"error","content":"pub fn error(\n  err_matcher: Matcher(a, b),\n) -&gt; Matcher(Result(c, a), b)\n\nSynonyms:\ngleamgen/matcher.error\ngleamgen/matcher error","url":"gleamgen/matcher.html#error"},{"doc":"gleamgen/matcher","title":"from_constructor0","content":"pub fn from_constructor0(\n  constructor: Constructor(a, #(), b),\n) -&gt; Matcher(a, Nil)\n\nSynonyms:\ngleamgen/matcher.from_constructor0\ngleamgen/matcher from_constructor0","url":"gleamgen/matcher.html#from_constructor0"},{"doc":"gleamgen/matcher","title":"from_constructor1","content":"pub fn from_constructor1(\n  constructor: Constructor(a, #(#(), b), c),\n  first: Matcher(b, d),\n) -&gt; Matcher(CustomType(a, c), d)\n\nSynonyms:\ngleamgen/matcher.from_constructor1\ngleamgen/matcher from_constructor1","url":"gleamgen/matcher.html#from_constructor1"},{"doc":"gleamgen/matcher","title":"from_constructor2","content":"pub fn from_constructor2(\n  constructor: Constructor(a, #(#(#(), b), c), d),\n  first: Matcher(b, e),\n  second: Matcher(c, f),\n) -&gt; Matcher(CustomType(a, d), #(e, f))\n\nSynonyms:\ngleamgen/matcher.from_constructor2\ngleamgen/matcher from_constructor2","url":"gleamgen/matcher.html#from_constructor2"},{"doc":"gleamgen/matcher","title":"from_constructor3","content":"pub fn from_constructor3(\n  constructor: Constructor(a, #(#(#(#(), b), c), d), e),\n  first: Matcher(b, f),\n  second: Matcher(c, g),\n  third: Matcher(d, h),\n) -&gt; Matcher(a, #(f, g, h))\n\nSynonyms:\ngleamgen/matcher.from_constructor3\ngleamgen/matcher from_constructor3","url":"gleamgen/matcher.html#from_constructor3"},{"doc":"gleamgen/matcher","title":"from_constructor4","content":"pub fn from_constructor4(\n  constructor: Constructor(a, #(#(#(#(#(), b), c), d), e), f),\n  first: Matcher(b, g),\n  second: Matcher(c, h),\n  third: Matcher(d, i),\n  fourth: Matcher(e, j),\n) -&gt; Matcher(a, #(g, h, i, j))\n\nSynonyms:\ngleamgen/matcher.from_constructor4\ngleamgen/matcher from_constructor4","url":"gleamgen/matcher.html#from_constructor4"},{"doc":"gleamgen/matcher","title":"from_constructor5","content":"pub fn from_constructor5(\n  constructor: Constructor(\n    a,\n    #(#(#(#(#(#(), b), c), d), e), f),\n    g,\n  ),\n  first: Matcher(b, h),\n  second: Matcher(c, i),\n  third: Matcher(d, j),\n  fourth: Matcher(e, k),\n  fifth: Matcher(f, l),\n) -&gt; Matcher(a, #(h, i, j, k, l))\n\nSynonyms:\ngleamgen/matcher.from_constructor5\ngleamgen/matcher from_constructor5","url":"gleamgen/matcher.html#from_constructor5"},{"doc":"gleamgen/matcher","title":"from_constructor6","content":"pub fn from_constructor6(\n  constructor: Constructor(\n    a,\n    #(#(#(#(#(#(#(), b), c), d), e), f), g),\n    h,\n  ),\n  first: Matcher(b, i),\n  second: Matcher(c, j),\n  third: Matcher(d, k),\n  fourth: Matcher(e, l),\n  fifth: Matcher(f, m),\n  sixth: Matcher(g, n),\n) -&gt; Matcher(a, #(i, j, k, l, m, n))\n\nSynonyms:\ngleamgen/matcher.from_constructor6\ngleamgen/matcher from_constructor6","url":"gleamgen/matcher.html#from_constructor6"},{"doc":"gleamgen/matcher","title":"from_constructor7","content":"pub fn from_constructor7(\n  constructor: Constructor(\n    a,\n    #(#(#(#(#(#(#(#(), b), c), d), e), f), g), h),\n    i,\n  ),\n  first: Matcher(b, j),\n  second: Matcher(c, k),\n  third: Matcher(d, l),\n  fourth: Matcher(e, m),\n  fifth: Matcher(f, n),\n  sixth: Matcher(g, o),\n  seventh: Matcher(h, p),\n) -&gt; Matcher(a, #(j, k, l, m, n, o, p))\n\nSynonyms:\ngleamgen/matcher.from_constructor7\ngleamgen/matcher from_constructor7","url":"gleamgen/matcher.html#from_constructor7"},{"doc":"gleamgen/matcher","title":"from_constructor8","content":"pub fn from_constructor8(\n  constructor: Constructor(\n    a,\n    #(#(#(#(#(#(#(#(#(), b), c), d), e), f), g), h), i),\n    j,\n  ),\n  first: Matcher(b, k),\n  second: Matcher(c, l),\n  third: Matcher(d, m),\n  fourth: Matcher(e, n),\n  fifth: Matcher(f, o),\n  sixth: Matcher(g, p),\n  seventh: Matcher(h, q),\n  eighth: Matcher(i, r),\n) -&gt; Matcher(a, #(k, l, m, n, o, p, q, r))\n\nSynonyms:\ngleamgen/matcher.from_constructor8\ngleamgen/matcher from_constructor8","url":"gleamgen/matcher.html#from_constructor8"},{"doc":"gleamgen/matcher","title":"from_constructor9","content":"pub fn from_constructor9(\n  constructor: Constructor(\n    a,\n    #(#(#(#(#(#(#(#(#(#(), b), c), d), e), f), g), h), i), j),\n    k,\n  ),\n  first: Matcher(b, l),\n  second: Matcher(c, m),\n  third: Matcher(d, n),\n  fourth: Matcher(e, o),\n  fifth: Matcher(f, p),\n  sixth: Matcher(g, q),\n  seventh: Matcher(h, r),\n  eighth: Matcher(i, s),\n  ninth: Matcher(j, t),\n) -&gt; Matcher(a, #(l, m, n, o, p, q, r, s, t))\n\nSynonyms:\ngleamgen/matcher.from_constructor9\ngleamgen/matcher from_constructor9","url":"gleamgen/matcher.html#from_constructor9"},{"doc":"gleamgen/matcher","title":"from_constructor_unchecked","content":"pub fn from_constructor_unchecked(\n  constructor: Constructor(a, b, c),\n  constructors: List(Matcher(Unchecked, Unchecked)),\n) -&gt; Matcher(d, List(Expression(Unchecked)))\n\nSynonyms:\ngleamgen/matcher.from_constructor_unchecked\ngleamgen/matcher from_constructor_unchecked","url":"gleamgen/matcher.html#from_constructor_unchecked"},{"doc":"gleamgen/matcher","title":"get_output","content":"pub fn get_output(matcher: Matcher(a, b)) -&gt; b\n\nSynonyms:\ngleamgen/matcher.get_output\ngleamgen/matcher get_output","url":"gleamgen/matcher.html#get_output"},{"doc":"gleamgen/matcher","title":"int_literal","content":"pub fn int_literal(literal: Int) -&gt; Matcher(Int, Nil)\n\nSynonyms:\ngleamgen/matcher.int_literal\ngleamgen/matcher int_literal","url":"gleamgen/matcher.html#int_literal"},{"doc":"gleamgen/matcher","title":"ok","content":"pub fn ok(ok_matcher: Matcher(a, b)) -&gt; Matcher(Result(a, c), b)\n\nSynonyms:\ngleamgen/matcher.ok\ngleamgen/matcher ok","url":"gleamgen/matcher.html#ok"},{"doc":"gleamgen/matcher","title":"or","content":"pub fn or(\n  first: Matcher(a, b),\n  second: Matcher(a, b),\n) -&gt; Matcher(a, b)\n Use either of the two matchers\n \n case_.new(expression.string(&quot;hello&quot;))\n |&gt; case_.with_matcher(\n   matcher.or(matcher.string_literal(&quot;hello&quot;), matcher.string_literal(&quot;hi&quot;)),\n   fn(_) { expression.string(&quot;world&quot;) },\n )\n |&gt; case_.with_matcher(matcher.variable(&quot;v&quot;), fn(v) {\n   expression.concat_string(v, expression.string(&quot; world&quot;))\n })\n |&gt; case_.build_expression()\n |&gt; expression.render(render.default_context())\n |&gt; render.to_string()\n // -&gt; &quot;case \\&quot;hello\\&quot; {\n  \\&quot;hello\\&quot; | \\&quot;hi\\&quot; -&gt; \\&quot;world\\&quot;\n  v -&gt; v &lt;&gt; \\&quot; world\\&quot;\n }&quot;,\n \nSynonyms:\ngleamgen/matcher.or\ngleamgen/matcher or","url":"gleamgen/matcher.html#or"},{"doc":"gleamgen/matcher","title":"render","content":"pub fn render(matcher: Matcher(Unchecked, Unchecked)) -&gt; Rendered\n\nSynonyms:\ngleamgen/matcher.render\ngleamgen/matcher render","url":"gleamgen/matcher.html#render"},{"doc":"gleamgen/matcher","title":"string_literal","content":"pub fn string_literal(literal: String) -&gt; Matcher(String, Nil)\n\nSynonyms:\ngleamgen/matcher.string_literal\ngleamgen/matcher string_literal","url":"gleamgen/matcher.html#string_literal"},{"doc":"gleamgen/matcher","title":"to_unchecked","content":"pub fn to_unchecked(\n  type_: Matcher(a, b),\n) -&gt; Matcher(Unchecked, Unchecked)\n\nSynonyms:\ngleamgen/matcher.to_unchecked\ngleamgen/matcher to_unchecked","url":"gleamgen/matcher.html#to_unchecked"},{"doc":"gleamgen/matcher","title":"tuple0","content":"pub fn tuple0() -&gt; Matcher(#(), Nil)\n\nSynonyms:\ngleamgen/matcher.tuple0\ngleamgen/matcher tuple0","url":"gleamgen/matcher.html#tuple0"},{"doc":"gleamgen/matcher","title":"tuple1","content":"pub fn tuple1(matcher: Matcher(a, b)) -&gt; Matcher(#(a), #(b))\n\nSynonyms:\ngleamgen/matcher.tuple1\ngleamgen/matcher tuple1","url":"gleamgen/matcher.html#tuple1"},{"doc":"gleamgen/matcher","title":"tuple2","content":"pub fn tuple2(\n  matcher1: Matcher(a, b),\n  matcher2: Matcher(c, d),\n) -&gt; Matcher(#(a, c), #(b, d))\n\nSynonyms:\ngleamgen/matcher.tuple2\ngleamgen/matcher tuple2","url":"gleamgen/matcher.html#tuple2"},{"doc":"gleamgen/matcher","title":"tuple3","content":"pub fn tuple3(\n  matcher1: Matcher(a, b),\n  matcher2: Matcher(c, d),\n  matcher3: Matcher(e, f),\n) -&gt; Matcher(#(a, c, e), #(b, d, f))\n\nSynonyms:\ngleamgen/matcher.tuple3\ngleamgen/matcher tuple3","url":"gleamgen/matcher.html#tuple3"},{"doc":"gleamgen/matcher","title":"tuple4","content":"pub fn tuple4(\n  matcher1: Matcher(a, b),\n  matcher2: Matcher(c, d),\n  matcher3: Matcher(e, f),\n  matcher4: Matcher(g, h),\n) -&gt; Matcher(#(a, c, e, g), #(b, d, f, h))\n\nSynonyms:\ngleamgen/matcher.tuple4\ngleamgen/matcher tuple4","url":"gleamgen/matcher.html#tuple4"},{"doc":"gleamgen/matcher","title":"tuple5","content":"pub fn tuple5(\n  matcher1: Matcher(a, b),\n  matcher2: Matcher(c, d),\n  matcher3: Matcher(e, f),\n  matcher4: Matcher(g, h),\n  matcher5: Matcher(i, j),\n) -&gt; Matcher(#(a, c, e, g, i), #(b, d, f, h, j))\n\nSynonyms:\ngleamgen/matcher.tuple5\ngleamgen/matcher tuple5","url":"gleamgen/matcher.html#tuple5"},{"doc":"gleamgen/matcher","title":"tuple6","content":"pub fn tuple6(\n  matcher1: Matcher(a, b),\n  matcher2: Matcher(c, d),\n  matcher3: Matcher(e, f),\n  matcher4: Matcher(g, h),\n  matcher5: Matcher(i, j),\n  matcher6: Matcher(k, l),\n) -&gt; Matcher(#(a, c, e, g, i, k), #(b, d, f, h, j, l))\n\nSynonyms:\ngleamgen/matcher.tuple6\ngleamgen/matcher tuple6","url":"gleamgen/matcher.html#tuple6"},{"doc":"gleamgen/matcher","title":"tuple7","content":"pub fn tuple7(\n  matcher1: Matcher(a, b),\n  matcher2: Matcher(c, d),\n  matcher3: Matcher(e, f),\n  matcher4: Matcher(g, h),\n  matcher5: Matcher(i, j),\n  matcher6: Matcher(k, l),\n  matcher7: Matcher(m, n),\n) -&gt; Matcher(#(a, c, e, g, i, k, m), #(b, d, f, h, j, l, n))\n\nSynonyms:\ngleamgen/matcher.tuple7\ngleamgen/matcher tuple7","url":"gleamgen/matcher.html#tuple7"},{"doc":"gleamgen/matcher","title":"tuple8","content":"pub fn tuple8(\n  matcher1: Matcher(a, b),\n  matcher2: Matcher(c, d),\n  matcher3: Matcher(e, f),\n  matcher4: Matcher(g, h),\n  matcher5: Matcher(i, j),\n  matcher6: Matcher(k, l),\n  matcher7: Matcher(m, n),\n  matcher8: Matcher(o, p),\n) -&gt; Matcher(#(a, c, e, g, i, k, m, o), #(b, d, f, h, j, l, n, p))\n\nSynonyms:\ngleamgen/matcher.tuple8\ngleamgen/matcher tuple8","url":"gleamgen/matcher.html#tuple8"},{"doc":"gleamgen/matcher","title":"tuple9","content":"pub fn tuple9(\n  matcher1: Matcher(a, b),\n  matcher2: Matcher(c, d),\n  matcher3: Matcher(e, f),\n  matcher4: Matcher(g, h),\n  matcher5: Matcher(i, j),\n  matcher6: Matcher(k, l),\n  matcher7: Matcher(m, n),\n  matcher8: Matcher(o, p),\n  matcher9: Matcher(q, r),\n) -&gt; Matcher(\n  #(a, c, e, g, i, k, m, o, q),\n  #(b, d, f, h, j, l, n, p, r),\n)\n\nSynonyms:\ngleamgen/matcher.tuple9\ngleamgen/matcher tuple9","url":"gleamgen/matcher.html#tuple9"},{"doc":"gleamgen/matcher","title":"variable","content":"pub fn variable(name: String) -&gt; Matcher(a, Expression(a))\n\nSynonyms:\ngleamgen/matcher.variable\ngleamgen/matcher variable","url":"gleamgen/matcher.html#variable"},{"doc":"gleamgen/matcher","title":"gleamgen/matcher","content":"","url":"gleamgen/matcher.html"},{"doc":"gleamgen/expression/block","title":"BlockBuilder","content":"pub opaque type BlockBuilder(type_)\n Blocks are used to group expressions together and are needed  to define local variables.\n \n  \n {\n   use x &lt;- block.with_let_declaration(&quot;x&quot;, expression.int(4))\n   use y &lt;- block.with_let_declaration(\n     &quot;y&quot;,\n     expression.math_operator(x, expression.Add, expression.int(5)),\n   )\n   block.ending_block(y)\n }\n |&gt; block.build()\n // type of Expression(Int)\n |&gt; expression.render(render.default_context())\n\n\n This will generate the following code:\n \n {\n   let x = 4\n   let y = x + 5\n   y\n }\n\n\n Blocks also can be created without the use syntax through `new` and `new_unchecked`\n\nSynonyms:\ngleamgen/expression/block.BlockBuilder\ngleamgen/expression/block BlockBuilder","url":"gleamgen/expression/block.html#BlockBuilder"},{"doc":"gleamgen/expression/block","title":"UseFunction","content":"pub type UseFunction(callback_args, ret) {\n  UseFunction(\n    function: Expression(types.Unchecked),\n    args: List(Expression(types.Unchecked)),\n  )\n}\n\nUseFunction(\n  function: Expression(types.Unchecked),\n  args: List(Expression(types.Unchecked)),\n)\n\n\nSynonyms:\ngleamgen/expression/block.UseFunction\ngleamgen/expression/block UseFunction","url":"gleamgen/expression/block.html#UseFunction"},{"doc":"gleamgen/expression/block","title":"build","content":"pub fn build(builder: BlockBuilder(a)) -&gt; Expression(a)\n\nSynonyms:\ngleamgen/expression/block.build\ngleamgen/expression/block build","url":"gleamgen/expression/block.html#build"},{"doc":"gleamgen/expression/block","title":"ending_block","content":"pub fn ending_block(expr: Expression(a)) -&gt; BlockBuilder(a)\n Used as the final expression in a block. If you want a dynamic final expression see `ending_unchecked`.\n\n This will set the type of the block to the type of the expression passed in.\nSynonyms:\ngleamgen/expression/block.ending_block\ngleamgen/expression/block ending_block","url":"gleamgen/expression/block.html#ending_block"},{"doc":"gleamgen/expression/block","title":"ending_unchecked","content":"pub fn ending_unchecked(\n  statements: List(Statement),\n) -&gt; BlockBuilder(a)\n\nSynonyms:\ngleamgen/expression/block.ending_unchecked\ngleamgen/expression/block ending_unchecked","url":"gleamgen/expression/block.html#ending_unchecked"},{"doc":"gleamgen/expression/block","title":"new","content":"pub fn new(\n  statements: List(Statement),\n  return: GeneratedType(a),\n) -&gt; Expression(a)\n\nSynonyms:\ngleamgen/expression/block.new\ngleamgen/expression/block new","url":"gleamgen/expression/block.html#new"},{"doc":"gleamgen/expression/block","title":"new_unchecked","content":"pub fn new_unchecked(\n  statements: List(Statement),\n) -&gt; Expression(a)\n\nSynonyms:\ngleamgen/expression/block.new_unchecked\ngleamgen/expression/block new_unchecked","url":"gleamgen/expression/block.html#new_unchecked"},{"doc":"gleamgen/expression/block","title":"use_function1","content":"pub fn use_function1(\n  func: Expression(fn(a, b) -&gt; c),\n  arg1: Expression(a),\n) -&gt; UseFunction(b, c)\n\nSynonyms:\ngleamgen/expression/block.use_function1\ngleamgen/expression/block use_function1","url":"gleamgen/expression/block.html#use_function1"},{"doc":"gleamgen/expression/block","title":"use_function2","content":"pub fn use_function2(\n  func: Expression(fn(a, b, c) -&gt; d),\n  arg1: Expression(a),\n  arg2: Expression(b),\n) -&gt; UseFunction(c, d)\n\nSynonyms:\ngleamgen/expression/block.use_function2\ngleamgen/expression/block use_function2","url":"gleamgen/expression/block.html#use_function2"},{"doc":"gleamgen/expression/block","title":"use_function3","content":"pub fn use_function3(\n  func: Expression(fn(a, b, c, d) -&gt; e),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n) -&gt; UseFunction(d, e)\n\nSynonyms:\ngleamgen/expression/block.use_function3\ngleamgen/expression/block use_function3","url":"gleamgen/expression/block.html#use_function3"},{"doc":"gleamgen/expression/block","title":"use_function4","content":"pub fn use_function4(\n  func: Expression(fn(a, b, c, d, e) -&gt; f),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n) -&gt; UseFunction(e, f)\n\nSynonyms:\ngleamgen/expression/block.use_function4\ngleamgen/expression/block use_function4","url":"gleamgen/expression/block.html#use_function4"},{"doc":"gleamgen/expression/block","title":"use_function5","content":"pub fn use_function5(\n  func: Expression(fn(a, b, c, d, e, f) -&gt; g),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n) -&gt; UseFunction(f, g)\n\nSynonyms:\ngleamgen/expression/block.use_function5\ngleamgen/expression/block use_function5","url":"gleamgen/expression/block.html#use_function5"},{"doc":"gleamgen/expression/block","title":"use_function6","content":"pub fn use_function6(\n  func: Expression(fn(a, b, c, d, e, f, g) -&gt; h),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n  arg6: Expression(f),\n) -&gt; UseFunction(g, h)\n\nSynonyms:\ngleamgen/expression/block.use_function6\ngleamgen/expression/block use_function6","url":"gleamgen/expression/block.html#use_function6"},{"doc":"gleamgen/expression/block","title":"use_function7","content":"pub fn use_function7(\n  func: Expression(fn(a, b, c, d, e, f, g, h) -&gt; i),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n  arg6: Expression(f),\n  arg7: Expression(g),\n) -&gt; UseFunction(h, i)\n\nSynonyms:\ngleamgen/expression/block.use_function7\ngleamgen/expression/block use_function7","url":"gleamgen/expression/block.html#use_function7"},{"doc":"gleamgen/expression/block","title":"use_function8","content":"pub fn use_function8(\n  func: Expression(fn(a, b, c, d, e, f, g, h, i) -&gt; j),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n  arg6: Expression(f),\n  arg7: Expression(g),\n  arg8: Expression(h),\n) -&gt; UseFunction(i, j)\n\nSynonyms:\ngleamgen/expression/block.use_function8\ngleamgen/expression/block use_function8","url":"gleamgen/expression/block.html#use_function8"},{"doc":"gleamgen/expression/block","title":"use_function9","content":"pub fn use_function9(\n  func: Expression(fn(a, b, c, d, e, f, g, h, i, j) -&gt; k),\n  arg1: Expression(a),\n  arg2: Expression(b),\n  arg3: Expression(c),\n  arg4: Expression(d),\n  arg5: Expression(e),\n  arg6: Expression(f),\n  arg7: Expression(g),\n  arg8: Expression(h),\n  arg9: Expression(i),\n) -&gt; UseFunction(j, k)\n\nSynonyms:\ngleamgen/expression/block.use_function9\ngleamgen/expression/block use_function9","url":"gleamgen/expression/block.html#use_function9"},{"doc":"gleamgen/expression/block","title":"use_function_unchecked","content":"pub fn use_function_unchecked(\n  func: Expression(a),\n  args: List(Expression(Unchecked)),\n) -&gt; UseFunction(b, c)\n\nSynonyms:\ngleamgen/expression/block.use_function_unchecked\ngleamgen/expression/block use_function_unchecked","url":"gleamgen/expression/block.html#use_function_unchecked"},{"doc":"gleamgen/expression/block","title":"with_expression","content":"pub fn with_expression(\n  expression: Expression(a),\n  handler: fn() -&gt; BlockBuilder(b),\n) -&gt; BlockBuilder(b)\n\nSynonyms:\ngleamgen/expression/block.with_expression\ngleamgen/expression/block with_expression","url":"gleamgen/expression/block.html#with_expression"},{"doc":"gleamgen/expression/block","title":"with_let_declaration","content":"pub fn with_let_declaration(\n  variable: String,\n  value: Expression(a),\n  handler: fn(Expression(a)) -&gt; BlockBuilder(b),\n) -&gt; BlockBuilder(b)\n\nSynonyms:\ngleamgen/expression/block.with_let_declaration\ngleamgen/expression/block with_let_declaration","url":"gleamgen/expression/block.html#with_let_declaration"},{"doc":"gleamgen/expression/block","title":"with_matching_let_declaration","content":"pub fn with_matching_let_declaration(\n  matcher: Matcher(a, b),\n  value: Expression(a),\n  assert_ assert_: Bool,\n  handler handler: fn(b) -&gt; BlockBuilder(c),\n) -&gt; BlockBuilder(c)\n\nSynonyms:\ngleamgen/expression/block.with_matching_let_declaration\ngleamgen/expression/block with_matching_let_declaration","url":"gleamgen/expression/block.html#with_matching_let_declaration"},{"doc":"gleamgen/expression/block","title":"with_statements_unchecked","content":"pub fn with_statements_unchecked(\n  statements: List(Statement),\n  handler: fn() -&gt; BlockBuilder(a),\n) -&gt; BlockBuilder(a)\n\nSynonyms:\ngleamgen/expression/block.with_statements_unchecked\ngleamgen/expression/block with_statements_unchecked","url":"gleamgen/expression/block.html#with_statements_unchecked"},{"doc":"gleamgen/expression/block","title":"with_use0","content":"pub fn with_use0(\n  use_function: UseFunction(fn() -&gt; a, a),\n  callback: fn() -&gt; BlockBuilder(a),\n) -&gt; BlockBuilder(a)\n\nSynonyms:\ngleamgen/expression/block.with_use0\ngleamgen/expression/block with_use0","url":"gleamgen/expression/block.html#with_use0"},{"doc":"gleamgen/expression/block","title":"with_use1","content":"pub fn with_use1(\n  use_function: UseFunction(fn(a) -&gt; b, b),\n  arg1: String,\n  callback: fn(Expression(a)) -&gt; BlockBuilder(b),\n) -&gt; BlockBuilder(b)\n\nSynonyms:\ngleamgen/expression/block.with_use1\ngleamgen/expression/block with_use1","url":"gleamgen/expression/block.html#with_use1"},{"doc":"gleamgen/expression/block","title":"with_use2","content":"pub fn with_use2(\n  use_function: UseFunction(fn(a, b) -&gt; c, c),\n  arg1: String,\n  arg2: String,\n  callback: fn(Expression(a), Expression(b)) -&gt; BlockBuilder(c),\n) -&gt; BlockBuilder(c)\n\nSynonyms:\ngleamgen/expression/block.with_use2\ngleamgen/expression/block with_use2","url":"gleamgen/expression/block.html#with_use2"},{"doc":"gleamgen/expression/block","title":"with_use3","content":"pub fn with_use3(\n  use_function: UseFunction(fn(a, b, c) -&gt; d, d),\n  arg1: String,\n  arg2: String,\n  arg3: String,\n  callback: fn(Expression(a), Expression(b), Expression(c)) -&gt;\n    BlockBuilder(d),\n) -&gt; BlockBuilder(d)\n\nSynonyms:\ngleamgen/expression/block.with_use3\ngleamgen/expression/block with_use3","url":"gleamgen/expression/block.html#with_use3"},{"doc":"gleamgen/expression/block","title":"with_use4","content":"pub fn with_use4(\n  use_function: UseFunction(fn(a, b, c, d) -&gt; e, e),\n  arg1: String,\n  arg2: String,\n  arg3: String,\n  arg4: String,\n  callback: fn(\n    Expression(a),\n    Expression(b),\n    Expression(c),\n    Expression(d),\n  ) -&gt; BlockBuilder(e),\n) -&gt; BlockBuilder(e)\n\nSynonyms:\ngleamgen/expression/block.with_use4\ngleamgen/expression/block with_use4","url":"gleamgen/expression/block.html#with_use4"},{"doc":"gleamgen/expression/block","title":"with_use5","content":"pub fn with_use5(\n  use_function: UseFunction(fn(a, b, c, d, e) -&gt; f, f),\n  arg1: String,\n  arg2: String,\n  arg3: String,\n  arg4: String,\n  arg5: String,\n  callback: fn(\n    Expression(a),\n    Expression(b),\n    Expression(c),\n    Expression(d),\n    Expression(e),\n  ) -&gt; BlockBuilder(f),\n) -&gt; BlockBuilder(f)\n\nSynonyms:\ngleamgen/expression/block.with_use5\ngleamgen/expression/block with_use5","url":"gleamgen/expression/block.html#with_use5"},{"doc":"gleamgen/expression/block","title":"with_use6","content":"pub fn with_use6(\n  use_function: UseFunction(fn(a, b, c, d, e, f) -&gt; g, g),\n  arg1: String,\n  arg2: String,\n  arg3: String,\n  arg4: String,\n  arg5: String,\n  arg6: String,\n  callback: fn(\n    Expression(a),\n    Expression(b),\n    Expression(c),\n    Expression(d),\n    Expression(e),\n    Expression(f),\n  ) -&gt; BlockBuilder(g),\n) -&gt; BlockBuilder(g)\n\nSynonyms:\ngleamgen/expression/block.with_use6\ngleamgen/expression/block with_use6","url":"gleamgen/expression/block.html#with_use6"},{"doc":"gleamgen/expression/block","title":"with_use7","content":"pub fn with_use7(\n  use_function: UseFunction(fn(a, b, c, d, e, f, g) -&gt; h, h),\n  arg1: String,\n  arg2: String,\n  arg3: String,\n  arg4: String,\n  arg5: String,\n  arg6: String,\n  arg7: String,\n  callback: fn(\n    Expression(a),\n    Expression(b),\n    Expression(c),\n    Expression(d),\n    Expression(e),\n    Expression(f),\n    Expression(g),\n  ) -&gt; BlockBuilder(h),\n) -&gt; BlockBuilder(h)\n\nSynonyms:\ngleamgen/expression/block.with_use7\ngleamgen/expression/block with_use7","url":"gleamgen/expression/block.html#with_use7"},{"doc":"gleamgen/expression/block","title":"with_use8","content":"pub fn with_use8(\n  use_function: UseFunction(fn(a, b, c, d, e, f, g, h) -&gt; i, i),\n  arg1: String,\n  arg2: String,\n  arg3: String,\n  arg4: String,\n  arg5: String,\n  arg6: String,\n  arg7: String,\n  arg8: String,\n  callback: fn(\n    Expression(a),\n    Expression(b),\n    Expression(c),\n    Expression(d),\n    Expression(e),\n    Expression(f),\n    Expression(g),\n    Expression(h),\n  ) -&gt; BlockBuilder(i),\n) -&gt; BlockBuilder(i)\n\nSynonyms:\ngleamgen/expression/block.with_use8\ngleamgen/expression/block with_use8","url":"gleamgen/expression/block.html#with_use8"},{"doc":"gleamgen/expression/block","title":"with_use9","content":"pub fn with_use9(\n  use_function: UseFunction(fn(a, b, c, d, e, f, g, h, i) -&gt; j, j),\n  arg1: String,\n  arg2: String,\n  arg3: String,\n  arg4: String,\n  arg5: String,\n  arg6: String,\n  arg7: String,\n  arg8: String,\n  arg9: String,\n  callback: fn(\n    Expression(a),\n    Expression(b),\n    Expression(c),\n    Expression(d),\n    Expression(e),\n    Expression(f),\n    Expression(g),\n    Expression(h),\n    Expression(i),\n  ) -&gt; BlockBuilder(j),\n) -&gt; BlockBuilder(j)\n\nSynonyms:\ngleamgen/expression/block.with_use9\ngleamgen/expression/block with_use9","url":"gleamgen/expression/block.html#with_use9"},{"doc":"gleamgen/expression/block","title":"with_use_unchecked","content":"pub fn with_use_unchecked(\n  use_function: UseFunction(a, b),\n  args: List(String),\n  callback: fn(List(Expression(Unchecked))) -&gt; BlockBuilder(b),\n) -&gt; BlockBuilder(b)\n\nSynonyms:\ngleamgen/expression/block.with_use_unchecked\ngleamgen/expression/block with_use_unchecked","url":"gleamgen/expression/block.html#with_use_unchecked"},{"doc":"gleamgen/expression/block","title":"gleamgen/expression/block","content":"","url":"gleamgen/expression/block.html"},{"doc":"gleamgen/expression/case_","title":"CaseExpression","content":"pub type CaseExpression(input, output) {\n  CaseExpression(\n    input_expression: Expression(input),\n    cases: List(\n      #(Matcher(Unchecked, Unchecked), Expression(output)),\n    ),\n  )\n}\n\nCaseExpression(\n  input_expression: Expression(input),\n  cases: List(\n    #(Matcher(Unchecked, Unchecked), Expression(output)),\n  ),\n)\n\n\nSynonyms:\ngleamgen/expression/case_.CaseExpression\ngleamgen/expression/case_ CaseExpression","url":"gleamgen/expression/case_.html#CaseExpression"},{"doc":"gleamgen/expression/case_","title":"build_expression","content":"pub fn build_expression(\n  case_: CaseExpression(a, b),\n) -&gt; Expression(b)\n\nSynonyms:\ngleamgen/expression/case_.build_expression\ngleamgen/expression/case_ build_expression","url":"gleamgen/expression/case_.html#build_expression"},{"doc":"gleamgen/expression/case_","title":"new","content":"pub fn new(\n  input_expression: Expression(a),\n) -&gt; CaseExpression(a, b)\n\nSynonyms:\ngleamgen/expression/case_.new\ngleamgen/expression/case_ new","url":"gleamgen/expression/case_.html#new"},{"doc":"gleamgen/expression/case_","title":"with_matcher","content":"pub fn with_matcher(\n  old: CaseExpression(a, b),\n  matcher: Matcher(a, c),\n  handler: fn(c) -&gt; Expression(b),\n) -&gt; CaseExpression(a, b)\n\nSynonyms:\ngleamgen/expression/case_.with_matcher\ngleamgen/expression/case_ with_matcher","url":"gleamgen/expression/case_.html#with_matcher"},{"doc":"gleamgen/expression/case_","title":"gleamgen/expression/case_","content":"","url":"gleamgen/expression/case_.html"},{"doc":"gleamgen/function","title":"Function","content":"pub type Function(type_, ret) {\n  Function(\n    args: List(#(String, types.GeneratedType(Unchecked))),\n    returns: types.GeneratedType(ret),\n    body: expression.Expression(ret),\n  )\n}\n\nFunction(\n  args: List(#(String, types.GeneratedType(Unchecked))),\n  returns: types.GeneratedType(ret),\n  body: expression.Expression(ret),\n)\n\n\nSynonyms:\ngleamgen/function.Function\ngleamgen/function Function","url":"gleamgen/function.html#Function"},{"doc":"gleamgen/function","title":"anonymous","content":"pub fn anonymous(function: Function(a, b)) -&gt; Expression(a)\n\nSynonyms:\ngleamgen/function.anonymous\ngleamgen/function anonymous","url":"gleamgen/function.html#anonymous"},{"doc":"gleamgen/function","title":"new0","content":"pub fn new0(\n  returns returns: GeneratedType(a),\n  handler handler: fn() -&gt; Expression(a),\n) -&gt; Function(fn(b) -&gt; a, a)\n\nSynonyms:\ngleamgen/function.new0\ngleamgen/function new0","url":"gleamgen/function.html#new0"},{"doc":"gleamgen/function","title":"new1","content":"pub fn new1(\n  arg1 arg1: #(String, GeneratedType(a)),\n  returns returns: GeneratedType(b),\n  handler handler: fn(Expression(a)) -&gt; Expression(b),\n) -&gt; Function(fn(a) -&gt; b, b)\n\nSynonyms:\ngleamgen/function.new1\ngleamgen/function new1","url":"gleamgen/function.html#new1"},{"doc":"gleamgen/function","title":"new2","content":"pub fn new2(\n  arg1 arg1: #(String, GeneratedType(a)),\n  arg2 arg2: #(String, GeneratedType(b)),\n  returns returns: GeneratedType(c),\n  handler handler: fn(Expression(a), Expression(b)) -&gt;\n    Expression(c),\n) -&gt; Function(fn(a, b) -&gt; c, c)\n\nSynonyms:\ngleamgen/function.new2\ngleamgen/function new2","url":"gleamgen/function.html#new2"},{"doc":"gleamgen/function","title":"new3","content":"pub fn new3(\n  arg1 arg1: #(String, GeneratedType(a)),\n  arg2 arg2: #(String, GeneratedType(b)),\n  arg3 arg3: #(String, GeneratedType(c)),\n  returns returns: GeneratedType(d),\n  handler handler: fn(Expression(a), Expression(b), Expression(c)) -&gt;\n    Expression(d),\n) -&gt; Function(fn(a, b, c) -&gt; d, d)\n\nSynonyms:\ngleamgen/function.new3\ngleamgen/function new3","url":"gleamgen/function.html#new3"},{"doc":"gleamgen/function","title":"new4","content":"pub fn new4(\n  arg1 arg1: #(String, GeneratedType(a)),\n  arg2 arg2: #(String, GeneratedType(b)),\n  arg3 arg3: #(String, GeneratedType(c)),\n  arg4 arg4: #(String, GeneratedType(d)),\n  returns returns: GeneratedType(e),\n  handler handler: fn(\n    Expression(a),\n    Expression(b),\n    Expression(c),\n    Expression(d),\n  ) -&gt; Expression(e),\n) -&gt; Function(fn(a, b, c, d) -&gt; e, e)\n\nSynonyms:\ngleamgen/function.new4\ngleamgen/function new4","url":"gleamgen/function.html#new4"},{"doc":"gleamgen/function","title":"new5","content":"pub fn new5(\n  arg1 arg1: #(String, GeneratedType(a)),\n  arg2 arg2: #(String, GeneratedType(b)),\n  arg3 arg3: #(String, GeneratedType(c)),\n  arg4 arg4: #(String, GeneratedType(d)),\n  arg5 arg5: #(String, GeneratedType(e)),\n  returns returns: GeneratedType(f),\n  handler handler: fn(\n    Expression(a),\n    Expression(b),\n    Expression(c),\n    Expression(d),\n    Expression(e),\n  ) -&gt; Expression(f),\n) -&gt; Function(fn(a, b, c, d, e) -&gt; f, f)\n\nSynonyms:\ngleamgen/function.new5\ngleamgen/function new5","url":"gleamgen/function.html#new5"},{"doc":"gleamgen/function","title":"new6","content":"pub fn new6(\n  arg1 arg1: #(String, GeneratedType(a)),\n  arg2 arg2: #(String, GeneratedType(b)),\n  arg3 arg3: #(String, GeneratedType(c)),\n  arg4 arg4: #(String, GeneratedType(d)),\n  arg5 arg5: #(String, GeneratedType(e)),\n  arg6 arg6: #(String, GeneratedType(f)),\n  returns returns: GeneratedType(g),\n  handler handler: fn(\n    Expression(a),\n    Expression(b),\n    Expression(c),\n    Expression(d),\n    Expression(e),\n    Expression(f),\n  ) -&gt; Expression(g),\n) -&gt; Function(fn(a, b, c, d, e, f) -&gt; g, g)\n\nSynonyms:\ngleamgen/function.new6\ngleamgen/function new6","url":"gleamgen/function.html#new6"},{"doc":"gleamgen/function","title":"new7","content":"pub fn new7(\n  arg1 arg1: #(String, GeneratedType(a)),\n  arg2 arg2: #(String, GeneratedType(b)),\n  arg3 arg3: #(String, GeneratedType(c)),\n  arg4 arg4: #(String, GeneratedType(d)),\n  arg5 arg5: #(String, GeneratedType(e)),\n  arg6 arg6: #(String, GeneratedType(f)),\n  arg7 arg7: #(String, GeneratedType(g)),\n  returns returns: GeneratedType(h),\n  handler handler: fn(\n    Expression(a),\n    Expression(b),\n    Expression(c),\n    Expression(d),\n    Expression(e),\n    Expression(f),\n    Expression(g),\n  ) -&gt; Expression(h),\n) -&gt; Function(fn(a, b, c, d, e, f, g) -&gt; h, h)\n\nSynonyms:\ngleamgen/function.new7\ngleamgen/function new7","url":"gleamgen/function.html#new7"},{"doc":"gleamgen/function","title":"new8","content":"pub fn new8(\n  arg1 arg1: #(String, GeneratedType(a)),\n  arg2 arg2: #(String, GeneratedType(b)),\n  arg3 arg3: #(String, GeneratedType(c)),\n  arg4 arg4: #(String, GeneratedType(d)),\n  arg5 arg5: #(String, GeneratedType(e)),\n  arg6 arg6: #(String, GeneratedType(f)),\n  arg7 arg7: #(String, GeneratedType(g)),\n  arg8 arg8: #(String, GeneratedType(h)),\n  returns returns: GeneratedType(i),\n  handler handler: fn(\n    Expression(a),\n    Expression(b),\n    Expression(c),\n    Expression(d),\n    Expression(e),\n    Expression(f),\n    Expression(g),\n    Expression(h),\n  ) -&gt; Expression(i),\n) -&gt; Function(fn(a, b, c, d, e, f, g, h) -&gt; i, i)\n\nSynonyms:\ngleamgen/function.new8\ngleamgen/function new8","url":"gleamgen/function.html#new8"},{"doc":"gleamgen/function","title":"new9","content":"pub fn new9(\n  arg1 arg1: #(String, GeneratedType(a)),\n  arg2 arg2: #(String, GeneratedType(b)),\n  arg3 arg3: #(String, GeneratedType(c)),\n  arg4 arg4: #(String, GeneratedType(d)),\n  arg5 arg5: #(String, GeneratedType(e)),\n  arg6 arg6: #(String, GeneratedType(f)),\n  arg7 arg7: #(String, GeneratedType(g)),\n  arg8 arg8: #(String, GeneratedType(h)),\n  arg9 arg9: #(String, GeneratedType(i)),\n  returns returns: GeneratedType(j),\n  handler handler: fn(\n    Expression(a),\n    Expression(b),\n    Expression(c),\n    Expression(d),\n    Expression(e),\n    Expression(f),\n    Expression(g),\n    Expression(h),\n    Expression(i),\n  ) -&gt; Expression(j),\n) -&gt; Function(fn(a, b, c, d, e, f, g, h, i) -&gt; j, j)\n\nSynonyms:\ngleamgen/function.new9\ngleamgen/function new9","url":"gleamgen/function.html#new9"},{"doc":"gleamgen/function","title":"render","content":"pub fn render(\n  func: Function(a, b),\n  context: Context,\n  name: Option(String),\n) -&gt; Rendered\n\nSynonyms:\ngleamgen/function.render\ngleamgen/function render","url":"gleamgen/function.html#render"},{"doc":"gleamgen/function","title":"to_unchecked","content":"pub fn to_unchecked(\n  type_: Function(a, b),\n) -&gt; Function(Unchecked, Unchecked)\n\nSynonyms:\ngleamgen/function.to_unchecked\ngleamgen/function to_unchecked","url":"gleamgen/function.html#to_unchecked"},{"doc":"gleamgen/function","title":"gleamgen/function","content":"","url":"gleamgen/function.html"},{"doc":"gleamgen/import_","title":"ImportedModule","content":"pub type ImportedModule {\n  ImportedModule(name: List(String), alias: Option(String))\n}\n\nImportedModule(name: List(String), alias: Option(String))\n\n\nSynonyms:\ngleamgen/import_.ImportedModule\ngleamgen/import_ ImportedModule","url":"gleamgen/import_.html#ImportedModule"},{"doc":"gleamgen/import_","title":"function0","content":"pub fn function0(\n  imported: ImportedModule,\n  func: fn() -&gt; a,\n) -&gt; Expression(fn() -&gt; a)\n Import an existing function from the module.\n Useful for importing functions and automatically getting their types\n Note that the function does not check if the provided function actually exists in the module.\n \n let dict_module = import_.new([&quot;gleam&quot;, &quot;dict&quot;])\n let dict_new = import_.function1(dict_module, dict.new)\n // dict.new ^ is a reference to actual function from gleam/dict\n // Therefore this type checks:\n expression.call0(dict_new)\n // but this does not:\n expression.call1(dict_new, expression.int(46))\n \nSynonyms:\ngleamgen/import_.function0\ngleamgen/import_ function0","url":"gleamgen/import_.html#function0"},{"doc":"gleamgen/import_","title":"function1","content":"pub fn function1(\n  imported: ImportedModule,\n  func: fn(a) -&gt; b,\n) -&gt; Expression(fn(a) -&gt; b)\n Import an existing function from the module.\n Useful for importing functions and automatically getting their types\n Note that the function does not check if the provided function actually exists in the module.\n \n let io_module = import_.new([&quot;gleam&quot;, &quot;io&quot;])\n let io_println = import_.function1(io_module, io.println)\n // io.println ^ is a reference to actual function from gleam/io\n // Therefore this type checks:\n expression.call1(io_println, expression.string(&quot;Hello, World!&quot;))\n // but this does not:\n expression.call1(io_println, expression.int(46))\n \nSynonyms:\ngleamgen/import_.function1\ngleamgen/import_ function1","url":"gleamgen/import_.html#function1"},{"doc":"gleamgen/import_","title":"function2","content":"pub fn function2(\n  imported: ImportedModule,\n  func: fn(a, b) -&gt; c,\n) -&gt; Expression(fn(a, b) -&gt; c)\n Import an existing function from the module.\n See `function1` for more details.\nSynonyms:\ngleamgen/import_.function2\ngleamgen/import_ function2","url":"gleamgen/import_.html#function2"},{"doc":"gleamgen/import_","title":"function3","content":"pub fn function3(\n  imported: ImportedModule,\n  func: fn(a, b, c) -&gt; d,\n) -&gt; Expression(fn(a, b, c) -&gt; d)\n Import an existing function from the module.\n See `function1` for more details.\nSynonyms:\ngleamgen/import_.function3\ngleamgen/import_ function3","url":"gleamgen/import_.html#function3"},{"doc":"gleamgen/import_","title":"function4","content":"pub fn function4(\n  imported: ImportedModule,\n  func: fn(a, b, c, d) -&gt; e,\n) -&gt; Expression(fn(a, b, c, d) -&gt; e)\n Import an existing function from the module.\n See `function1` for more details.\nSynonyms:\ngleamgen/import_.function4\ngleamgen/import_ function4","url":"gleamgen/import_.html#function4"},{"doc":"gleamgen/import_","title":"function5","content":"pub fn function5(\n  imported: ImportedModule,\n  func: fn(a, b, c, d, e) -&gt; f,\n) -&gt; Expression(fn(a, b, c, d, e) -&gt; f)\n Import an existing function from the module.\n See `function1` for more details.\nSynonyms:\ngleamgen/import_.function5\ngleamgen/import_ function5","url":"gleamgen/import_.html#function5"},{"doc":"gleamgen/import_","title":"function6","content":"pub fn function6(\n  imported: ImportedModule,\n  func: fn(a, b, c, d, e, f) -&gt; g,\n) -&gt; Expression(fn(a, b, c, d, e, f) -&gt; g)\n Import an existing function from the module.\n See `function1` for more details.\nSynonyms:\ngleamgen/import_.function6\ngleamgen/import_ function6","url":"gleamgen/import_.html#function6"},{"doc":"gleamgen/import_","title":"function7","content":"pub fn function7(\n  imported: ImportedModule,\n  func: fn(a, b, c, d, e, f, g) -&gt; h,\n) -&gt; Expression(fn(a, b, c, d, e, f, g) -&gt; h)\n Import an existing function from the module.\n See `function1` for more details.\nSynonyms:\ngleamgen/import_.function7\ngleamgen/import_ function7","url":"gleamgen/import_.html#function7"},{"doc":"gleamgen/import_","title":"function8","content":"pub fn function8(\n  imported: ImportedModule,\n  func: fn(a, b, c, d, e, f, g, h) -&gt; i,\n) -&gt; Expression(fn(a, b, c, d, e, f, g, h) -&gt; i)\n Import an existing function from the module.\n See `function1` for more details.\nSynonyms:\ngleamgen/import_.function8\ngleamgen/import_ function8","url":"gleamgen/import_.html#function8"},{"doc":"gleamgen/import_","title":"function9","content":"pub fn function9(\n  imported: ImportedModule,\n  func: fn(a, b, c, d, e, f, g, h, i) -&gt; j,\n) -&gt; Expression(fn(a, b, c, d, e, f, g, h, i) -&gt; j)\n Import an existing function from the module.\n See `function1` for more details.\nSynonyms:\ngleamgen/import_.function9\ngleamgen/import_ function9","url":"gleamgen/import_.html#function9"},{"doc":"gleamgen/import_","title":"new","content":"pub fn new(name: List(String)) -&gt; ImportedModule\n\nSynonyms:\ngleamgen/import_.new\ngleamgen/import_ new","url":"gleamgen/import_.html#new"},{"doc":"gleamgen/import_","title":"new_with_alias","content":"pub fn new_with_alias(\n  name: List(String),\n  alias: String,\n) -&gt; ImportedModule\n\nSynonyms:\ngleamgen/import_.new_with_alias\ngleamgen/import_ new_with_alias","url":"gleamgen/import_.html#new_with_alias"},{"doc":"gleamgen/import_","title":"unchecked_ident","content":"pub fn unchecked_ident(\n  imported: ImportedModule,\n  name: String,\n) -&gt; Expression(a)\n\nSynonyms:\ngleamgen/import_.unchecked_ident\ngleamgen/import_ unchecked_ident","url":"gleamgen/import_.html#unchecked_ident"},{"doc":"gleamgen/import_","title":"unchecked_type","content":"pub fn unchecked_type(\n  imported: ImportedModule,\n  name: String,\n) -&gt; CustomType(a, b)\n\nSynonyms:\ngleamgen/import_.unchecked_type\ngleamgen/import_ unchecked_type","url":"gleamgen/import_.html#unchecked_type"},{"doc":"gleamgen/import_","title":"value_of_type","content":"pub fn value_of_type(\n  imported: ImportedModule,\n  name: String,\n  type_: GeneratedType(a),\n) -&gt; Expression(a)\n\nSynonyms:\ngleamgen/import_.value_of_type\ngleamgen/import_ value_of_type","url":"gleamgen/import_.html#value_of_type"},{"doc":"gleamgen/import_","title":"gleamgen/import_","content":"","url":"gleamgen/import_.html"},{"doc":"gleamgen/module","title":"Attribute","content":"pub type Attribute {\n  ExternalErlang\n  ExternalJavascript\n  Deprecated(String)\n  Internal\n}\n\nExternalErlang\n\n\nExternalJavascript\n\n\nDeprecated(String)\n\n\nInternal\n\n\nSynonyms:\ngleamgen/module.Attribute\ngleamgen/module Attribute","url":"gleamgen/module.html#Attribute"},{"doc":"gleamgen/module","title":"Definable","content":"pub type Definable {\n  Function(function.Function(Unchecked, Unchecked))\n  CustomTypeBuilder(\n    custom.CustomTypeBuilder(Unchecked, Nil, Nil),\n  )\n  Constant(Expression(Unchecked))\n  TypeAlias(types.GeneratedType(Unchecked))\n}\n\nFunction(function.Function(Unchecked, Unchecked))\n\n\nCustomTypeBuilder(custom.CustomTypeBuilder(Unchecked, Nil, Nil))\n\n\nConstant(Expression(Unchecked))\n\n\nTypeAlias(types.GeneratedType(Unchecked))\n\n\nSynonyms:\ngleamgen/module.Definable\ngleamgen/module Definable","url":"gleamgen/module.html#Definable"},{"doc":"gleamgen/module","title":"Definition","content":"pub type Definition {\n  Definition(details: DefinitionDetails, value: Definable)\n}\n\nDefinition(details: DefinitionDetails, value: Definable)\n\n\nSynonyms:\ngleamgen/module.Definition\ngleamgen/module Definition","url":"gleamgen/module.html#Definition"},{"doc":"gleamgen/module","title":"DefinitionDetails","content":"pub type DefinitionDetails {\n  DefinitionDetails(\n    name: String,\n    is_public: Bool,\n    attributes: List(Attribute),\n  )\n}\n\nDefinitionDetails(\n  name: String,\n  is_public: Bool,\n  attributes: List(Attribute),\n)\n\n\nSynonyms:\ngleamgen/module.DefinitionDetails\ngleamgen/module DefinitionDetails","url":"gleamgen/module.html#DefinitionDetails"},{"doc":"gleamgen/module","title":"Module","content":"pub type Module {\n  Module(\n    definitions: List(Definition),\n    imports: List(import_.ImportedModule),\n  )\n}\n\nModule(\n  definitions: List(Definition),\n  imports: List(import_.ImportedModule),\n)\n\n\nSynonyms:\ngleamgen/module.Module\ngleamgen/module Module","url":"gleamgen/module.html#Module"},{"doc":"gleamgen/module","title":"eof","content":"pub fn eof() -&gt; Module\n\nSynonyms:\ngleamgen/module.eof\ngleamgen/module eof","url":"gleamgen/module.html#eof"},{"doc":"gleamgen/module","title":"render","content":"pub fn render(module: Module, context: Context) -&gt; Rendered\n\nSynonyms:\ngleamgen/module.render\ngleamgen/module render","url":"gleamgen/module.html#render"},{"doc":"gleamgen/module","title":"render_imported_module","content":"pub fn render_imported_module(module: ImportedModule) -&gt; Rendered\n\nSynonyms:\ngleamgen/module.render_imported_module\ngleamgen/module render_imported_module","url":"gleamgen/module.html#render_imported_module"},{"doc":"gleamgen/module","title":"with_constant","content":"pub fn with_constant(\n  details: DefinitionDetails,\n  value: Expression(a),\n  handler: fn(Expression(a)) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_constant\ngleamgen/module with_constant","url":"gleamgen/module.html#with_constant"},{"doc":"gleamgen/module","title":"with_custom_type1","content":"pub fn with_custom_type1(\n  details: DefinitionDetails,\n  type_: CustomTypeBuilder(a, #(#(), b), c),\n  handler: fn(CustomType(a, c), Constructor(a, b, c)) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_custom_type1\ngleamgen/module with_custom_type1","url":"gleamgen/module.html#with_custom_type1"},{"doc":"gleamgen/module","title":"with_custom_type2","content":"pub fn with_custom_type2(\n  details: DefinitionDetails,\n  type_: CustomTypeBuilder(a, #(#(#(), b), c), d),\n  handler: fn(\n    CustomType(a, d),\n    Constructor(a, b, d),\n    Constructor(a, c, d),\n  ) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_custom_type2\ngleamgen/module with_custom_type2","url":"gleamgen/module.html#with_custom_type2"},{"doc":"gleamgen/module","title":"with_custom_type3","content":"pub fn with_custom_type3(\n  details: DefinitionDetails,\n  type_: CustomTypeBuilder(a, #(#(#(#(), b), c), d), e),\n  handler: fn(\n    CustomType(a, e),\n    Constructor(a, b, e),\n    Constructor(a, c, e),\n    Constructor(a, d, e),\n  ) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_custom_type3\ngleamgen/module with_custom_type3","url":"gleamgen/module.html#with_custom_type3"},{"doc":"gleamgen/module","title":"with_custom_type4","content":"pub fn with_custom_type4(\n  details: DefinitionDetails,\n  type_: CustomTypeBuilder(a, #(#(#(#(#(), b), c), d), e), f),\n  handler: fn(\n    CustomType(a, f),\n    Constructor(a, b, f),\n    Constructor(a, c, f),\n    Constructor(a, d, f),\n    Constructor(a, e, f),\n  ) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_custom_type4\ngleamgen/module with_custom_type4","url":"gleamgen/module.html#with_custom_type4"},{"doc":"gleamgen/module","title":"with_custom_type5","content":"pub fn with_custom_type5(\n  details: DefinitionDetails,\n  type_: CustomTypeBuilder(\n    a,\n    #(#(#(#(#(#(), b), c), d), e), f),\n    g,\n  ),\n  handler: fn(\n    CustomType(a, g),\n    Constructor(a, b, g),\n    Constructor(a, c, g),\n    Constructor(a, d, g),\n    Constructor(a, e, g),\n    Constructor(a, f, g),\n  ) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_custom_type5\ngleamgen/module with_custom_type5","url":"gleamgen/module.html#with_custom_type5"},{"doc":"gleamgen/module","title":"with_custom_type6","content":"pub fn with_custom_type6(\n  details: DefinitionDetails,\n  type_: CustomTypeBuilder(\n    a,\n    #(#(#(#(#(#(#(), b), c), d), e), f), g),\n    h,\n  ),\n  handler: fn(\n    CustomType(a, h),\n    Constructor(a, b, h),\n    Constructor(a, c, h),\n    Constructor(a, d, h),\n    Constructor(a, e, h),\n    Constructor(a, f, h),\n    Constructor(a, g, h),\n  ) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_custom_type6\ngleamgen/module with_custom_type6","url":"gleamgen/module.html#with_custom_type6"},{"doc":"gleamgen/module","title":"with_custom_type7","content":"pub fn with_custom_type7(\n  details: DefinitionDetails,\n  type_: CustomTypeBuilder(\n    a,\n    #(#(#(#(#(#(#(#(), b), c), d), e), f), g), h),\n    i,\n  ),\n  handler: fn(\n    CustomType(a, i),\n    Constructor(a, b, i),\n    Constructor(a, c, i),\n    Constructor(a, d, i),\n    Constructor(a, e, i),\n    Constructor(a, f, i),\n    Constructor(a, g, i),\n    Constructor(a, h, i),\n  ) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_custom_type7\ngleamgen/module with_custom_type7","url":"gleamgen/module.html#with_custom_type7"},{"doc":"gleamgen/module","title":"with_custom_type8","content":"pub fn with_custom_type8(\n  details: DefinitionDetails,\n  type_: CustomTypeBuilder(\n    a,\n    #(#(#(#(#(#(#(#(#(), b), c), d), e), f), g), h), i),\n    j,\n  ),\n  handler: fn(\n    CustomType(a, j),\n    Constructor(a, b, j),\n    Constructor(a, c, j),\n    Constructor(a, d, j),\n    Constructor(a, e, j),\n    Constructor(a, f, j),\n    Constructor(a, g, j),\n    Constructor(a, h, j),\n    Constructor(a, i, j),\n  ) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_custom_type8\ngleamgen/module with_custom_type8","url":"gleamgen/module.html#with_custom_type8"},{"doc":"gleamgen/module","title":"with_custom_type9","content":"pub fn with_custom_type9(\n  details: DefinitionDetails,\n  type_: CustomTypeBuilder(\n    a,\n    #(#(#(#(#(#(#(#(#(#(), b), c), d), e), f), g), h), i), j),\n    k,\n  ),\n  handler: fn(\n    CustomType(a, k),\n    Constructor(a, b, k),\n    Constructor(a, c, k),\n    Constructor(a, d, k),\n    Constructor(a, e, k),\n    Constructor(a, f, k),\n    Constructor(a, g, k),\n    Constructor(a, h, k),\n    Constructor(a, i, k),\n    Constructor(a, j, k),\n  ) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_custom_type9\ngleamgen/module with_custom_type9","url":"gleamgen/module.html#with_custom_type9"},{"doc":"gleamgen/module","title":"with_custom_type_unchecked","content":"pub fn with_custom_type_unchecked(\n  details: DefinitionDetails,\n  type_: CustomTypeBuilder(a, Unchecked, b),\n  handler: fn(\n    CustomType(a, b),\n    List(Constructor(a, Unchecked, b)),\n  ) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_custom_type_unchecked\ngleamgen/module with_custom_type_unchecked","url":"gleamgen/module.html#with_custom_type_unchecked"},{"doc":"gleamgen/module","title":"with_function","content":"pub fn with_function(\n  details: DefinitionDetails,\n  func: Function(a, b),\n  handler: fn(Expression(a)) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_function\ngleamgen/module with_function","url":"gleamgen/module.html#with_function"},{"doc":"gleamgen/module","title":"with_import","content":"pub fn with_import(\n  module: ImportedModule,\n  handler: fn(ImportedModule) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_import\ngleamgen/module with_import","url":"gleamgen/module.html#with_import"},{"doc":"gleamgen/module","title":"with_imports_unchecked","content":"pub fn with_imports_unchecked(\n  modules: List(ImportedModule),\n  handler: fn(List(ImportedModule)) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_imports_unchecked\ngleamgen/module with_imports_unchecked","url":"gleamgen/module.html#with_imports_unchecked"},{"doc":"gleamgen/module","title":"with_type_alias","content":"pub fn with_type_alias(\n  details: DefinitionDetails,\n  type_: GeneratedType(a),\n  handler: fn(GeneratedType(a)) -&gt; Module,\n) -&gt; Module\n\nSynonyms:\ngleamgen/module.with_type_alias\ngleamgen/module with_type_alias","url":"gleamgen/module.html#with_type_alias"},{"doc":"gleamgen/module","title":"gleamgen/module","content":"","url":"gleamgen/module.html"}]);